@@ -13,15 +13,16 @@ import com.fasterxml.jackson.databind.deser.ValueInstantiator;
 import com.fasterxml.jackson.databind.deser.impl.PropertyBasedCreator;
 import com.fasterxml.jackson.databind.deser.impl.PropertyValueBuffer;
 import com.fasterxml.jackson.databind.jsontype.TypeDeserializer;
+import com.fasterxml.jackson.databind.type.LogicalType;
 import com.fasterxml.jackson.databind.util.ClassUtil;
 
 /**
  * Deserializer for {@link EnumMap} values.
  * <p>
  * Note: casting within this class is all messed up -- just could not figure out a way
- * to properly deal with recursive definition of "EnumMap&lt;K extends Enum&lt;K>, V>
+ * to properly deal with recursive definition of {@code EnumMap<K extends Enum<K>, V>}
  */
-@SuppressWarnings({ "unchecked", "rawtypes" }) 
+@SuppressWarnings({ "unchecked", "rawtypes" })
 public class EnumMapDeserializer
     extends ContainerDeserializerBase<EnumMap<?,?>>
     implements ContextualDeserializer, ResolvableDeserializer
@@ -41,7 +42,7 @@ public class EnumMapDeserializer
     protected final TypeDeserializer _valueTypeDeserializer;
 
     // // Instance construction settings:
-    
+
     /**
      * @since 2.9
      */
@@ -59,7 +60,7 @@ public class EnumMapDeserializer
      * that takes one or more named properties as argument(s),
      * this creator is used for instantiation.
      */
-    protected PropertyBasedCreator _propertyBasedCreator;    
+    protected PropertyBasedCreator _propertyBasedCreator;
 
     /*
     /**********************************************************
@@ -106,7 +107,7 @@ public class EnumMapDeserializer
     {
         this(mapType, null, keyDeser, valueDeser, vtd, null);
     }
-    
+
     public EnumMapDeserializer withResolved(KeyDeserializer keyDeserializer,
             JsonDeserializer<?> valueDeserializer, TypeDeserializer valueTypeDeser,
             NullValueProvider nuller)
@@ -124,7 +125,7 @@ public class EnumMapDeserializer
     /* Validation, post-processing (ResolvableDeserializer)
     /**********************************************************
      */
-    
+
     @Override
     public void resolve(DeserializationContext ctxt) throws JsonMappingException
     {
@@ -200,6 +201,11 @@ public class EnumMapDeserializer
                 && (_valueTypeDeserializer == null);
     }
 
+    @Override // since 2.12
+    public LogicalType logicalType() {
+        return LogicalType.Map;
+    }
+
     /*
     /**********************************************************
     /* ContainerDeserializerBase API
@@ -211,7 +217,11 @@ public class EnumMapDeserializer
         return _valueDeserializer;
     }
 
-    // Must override since we do not expose ValueInstantiator
+    @Override
+    public ValueInstantiator getValueInstantiator() {
+        return _valueInstantiator;
+    }
+
     @Override // since 2.9
     public Object getEmptyValue(DeserializationContext ctxt) throws JsonMappingException {
         return constructMap(ctxt);
@@ -222,7 +232,7 @@ public class EnumMapDeserializer
     /* Actual deserialization
     /**********************************************************
      */
-    
+
     @Override
     public EnumMap<?,?> deserialize(JsonParser p, DeserializationContext ctxt)
         throws IOException
@@ -234,18 +244,21 @@ public class EnumMapDeserializer
             return (EnumMap<?,?>) _valueInstantiator.createUsingDelegate(ctxt,
                     _delegateDeserializer.deserialize(p, ctxt));
         }
-        // Ok: must point to START_OBJECT
-        JsonToken t = p.getCurrentToken();
-        if ((t != JsonToken.START_OBJECT) && (t != JsonToken.FIELD_NAME) && (t != JsonToken.END_OBJECT)) {
+
+        switch (p.currentTokenId()) {
+        case JsonTokenId.ID_START_OBJECT:
+        case JsonTokenId.ID_END_OBJECT:
+        case JsonTokenId.ID_FIELD_NAME:
+            return deserialize(p, ctxt, constructMap(ctxt));
+        case JsonTokenId.ID_STRING:
             // (empty) String may be ok however; or single-String-arg ctor
-            if (t == JsonToken.VALUE_STRING) {
-                return (EnumMap<?,?>) _valueInstantiator.createFromString(ctxt, p.getText());
-            }
-            // slightly redundant (since String was passed above), but also handles empty array case:
-            return _deserializeFromEmpty(p, ctxt);
+            return _deserializeFromString(p, ctxt);
+        case JsonTokenId.ID_START_ARRAY:
+            // Empty array, or single-value wrapped in array?
+            return _deserializeFromArray(p, ctxt);
+        default:
         }
-        EnumMap result = constructMap(ctxt);
-        return deserialize(p, ctxt, result);
+        return (EnumMap<?,?>) ctxt.handleUnexpectedToken(getValueType(ctxt), p);
     }
 
     @Override
@@ -254,23 +267,20 @@ public class EnumMapDeserializer
         throws IOException
     {
         // [databind#631]: Assign current value, to be accessible by custom deserializers
-        p.setCurrentValue(result);
-
-        final JsonDeserializer<Object> valueDes = _valueDeserializer;
-        final TypeDeserializer typeDeser = _valueTypeDeserializer;
+        p.assignCurrentValue(result);
 
         String keyStr;
         if (p.isExpectedStartObjectToken()) {
             keyStr = p.nextFieldName();
         } else {
-            JsonToken t = p.getCurrentToken();
+            JsonToken t = p.currentToken();
             if (t != JsonToken.FIELD_NAME) {
                 if (t == JsonToken.END_OBJECT) {
                     return result;
                 }
                 ctxt.reportWrongTokenException(this, JsonToken.FIELD_NAME, null);
             }
-            keyStr = p.getCurrentName();
+            keyStr = p.currentName();
         }
 
         for (; keyStr != null; keyStr = p.nextFieldName()) {
@@ -298,14 +308,20 @@ public class EnumMapDeserializer
                     if (_skipNullValues) {
                         continue;
                     }
-                    value = _nullProvider.getNullValue(ctxt);
-                } else if (typeDeser == null) {
-                    value =  valueDes.deserialize(p, ctxt);
+                    value = null;
                 } else {
-                    value = valueDes.deserializeWithType(p, ctxt, typeDeser);
+                    value = _deserializeNoNullChecks(p, ctxt);
+                }
+
+                if (value == null) {
+                    value = _nullProvider.getNullValue(ctxt);
+
+                    if (value == null && _skipNullValues) {
+                        continue;
+                    }
                 }
             } catch (Exception e) {
-                return wrapAndThrow(e, result, keyStr);
+                return wrapAndThrow(ctxt, e, result, keyStr);
             }
             result.put(key, value);
         }
@@ -347,7 +363,7 @@ public class EnumMapDeserializer
         if (p.isExpectedStartObjectToken()) {
             keyName = p.nextFieldName();
         } else if (p.hasToken(JsonToken.FIELD_NAME)) {
-            keyName = p.getCurrentName();
+            keyName = p.currentName();
         } else {
             keyName = null;
         }
@@ -364,7 +380,7 @@ public class EnumMapDeserializer
                     try {
                         result = (EnumMap<?,?>)creator.build(ctxt, buffer);
                     } catch (Exception e) {
-                        return wrapAndThrow(e, _containerType.getRawClass(), keyName);
+                        return wrapAndThrow(ctxt, e, _containerType.getRawClass(), keyName);
                     }
                     return deserialize(p, ctxt, result);
                 }
@@ -385,21 +401,27 @@ public class EnumMapDeserializer
                 p.skipChildren();
                 continue;
             }
-            Object value; 
+            Object value;
 
             try {
                 if (t == JsonToken.VALUE_NULL) {
                     if (_skipNullValues) {
                         continue;
                     }
-                    value = _nullProvider.getNullValue(ctxt);
-                } else if (_valueTypeDeserializer == null) {
-                    value = _valueDeserializer.deserialize(p, ctxt);
+                    value = null;
                 } else {
-                    value = _valueDeserializer.deserializeWithType(p, ctxt, _valueTypeDeserializer);
+                    value = _deserializeNoNullChecks(p, ctxt);
+                }
+
+                if (value == null) {
+                    value = _nullProvider.getNullValue(ctxt);
+
+                    if (value == null && _skipNullValues) {
+                        continue;
+                    }
                 }
             } catch (Exception e) {
-                wrapAndThrow(e, _containerType.getRawClass(), keyName);
+                wrapAndThrow(ctxt, e, _containerType.getRawClass(), keyName);
                 return null;
             }
             buffer.bufferMapProperty(key, value);
@@ -409,8 +431,24 @@ public class EnumMapDeserializer
         try {
             return (EnumMap<?,?>)creator.build(ctxt, buffer);
         } catch (Exception e) {
-            wrapAndThrow(e, _containerType.getRawClass(), keyName);
+            wrapAndThrow(ctxt, e, _containerType.getRawClass(), keyName);
             return null;
         }
     }
+
+    /**
+     * Deserialize the content of the map.
+     * If _valueTypeDeserializer is null, use _valueDeserializer.deserialize; if non-null,
+     * use _valueDeserializer.deserializeWithType to deserialize value.
+     * This method only performs deserialization and does not consider _skipNullValues, _nullProvider, etc.
+     * @since 2.19.2
+     */
+    protected Object _deserializeNoNullChecks(JsonParser p, DeserializationContext ctxt)
+            throws IOException
+    {
+        if (_valueTypeDeserializer == null) {
+            return _valueDeserializer.deserialize(p, ctxt);
+        }
+        return _valueDeserializer.deserializeWithType(p, ctxt, _valueTypeDeserializer);
+    }
 }
