@@ -21,12 +21,12 @@ public final class AnnotatedParameter
      * Member (method, constructor) that this parameter belongs to
      */
     protected final AnnotatedWithParams _owner;
-    
+
     /**
      * JDK type of the parameter, possibly contains generic type information
      */
     protected final JavaType _type;
-    
+
     /**
      * Index of the parameter within argument list
      */
@@ -93,12 +93,6 @@ public final class AnnotatedParameter
         return _type;
     }
 
-    @Deprecated
-    @Override
-    public Type getGenericType() {
-        return _owner.getGenericParameterType(_index);
-    }
-
     /*
     /**********************************************************
     /* AnnotatedMember extras
@@ -112,9 +106,8 @@ public final class AnnotatedParameter
 
     @Override
     public Member getMember() {
-        /* This is bit tricky: since there is no JDK equivalent; can either
-         * return null or owner... let's do latter, for now.
-         */
+        // This is bit tricky: since there is no JDK equivalent; can either
+        // return null or owner... let's do latter, for now.
         return _owner.getMember();
     }
 
@@ -143,14 +136,14 @@ public final class AnnotatedParameter
     /**
      * Accessor for 'owner' of this parameter; method or constructor that
      * has this parameter as member of its argument list.
-     * 
+     *
      * @return Owner (member or creator) object of this parameter
      */
     public AnnotatedWithParams getOwner() { return _owner; }
-    
+
     /**
      * Accessor for index of this parameter within argument list
-     * 
+     *
      * @return Index of this parameter within argument list
      */
     public int getIndex() { return _index; }
@@ -160,12 +153,12 @@ public final class AnnotatedParameter
     /* Other
     /********************************************************
      */
-    
+
     @Override
     public int hashCode() {
         return _owner.hashCode() + _index;
     }
-    
+
     @Override
     public boolean equals(Object o) {
         if (o == this) return true;
@@ -175,7 +168,7 @@ public final class AnnotatedParameter
         AnnotatedParameter other = (AnnotatedParameter) o;
         return other._owner.equals(_owner) && (other._index == _index);
     }
-    
+
     @Override
     public String toString() {
         return "[parameter #"+getIndex()+", annotations: "+_annotations+"]";
