@@ -1,5 +1,6 @@
 package com.fasterxml.jackson.databind.ser;
 
+import java.io.IOException;
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Field;
 import java.lang.reflect.Method;
@@ -7,6 +8,7 @@ import java.lang.reflect.Type;
 import java.util.HashMap;
 
 import com.fasterxml.jackson.annotation.JsonInclude;
+
 import com.fasterxml.jackson.core.JsonGenerator;
 import com.fasterxml.jackson.core.SerializableString;
 import com.fasterxml.jackson.core.io.SerializedString;
@@ -14,7 +16,6 @@ import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.annotation.JacksonStdImpl;
 import com.fasterxml.jackson.databind.introspect.*;
 import com.fasterxml.jackson.databind.jsonFormatVisitors.JsonObjectFormatVisitor;
-import com.fasterxml.jackson.databind.jsonschema.SchemaAware;
 import com.fasterxml.jackson.databind.jsontype.TypeSerializer;
 import com.fasterxml.jackson.databind.node.ObjectNode;
 import com.fasterxml.jackson.databind.ser.impl.PropertySerializerMap;
@@ -66,7 +67,7 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
 
     /**
      * Wrapper name to use for this element, if any
-     * 
+     *
      * @since 2.2
      */
     protected final PropertyName _wrapperName;
@@ -222,8 +223,7 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
 
         _declaredType = declaredType;
         _serializer = (JsonSerializer<Object>) ser;
-        _dynamicSerializers = (ser == null) ? PropertySerializerMap
-                .emptyForProperties() : null;
+        _dynamicSerializers = (ser == null) ? PropertySerializerMap.emptyForProperties() : null;
         _typeSerializer = typeSer;
         _cfgSerializationType = serType;
 
@@ -263,7 +263,7 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
      * Constructor that may be of use to virtual properties, when there is need
      * for the zero-arg ("default") constructor, and actual initialization is
      * done after constructor call.
-     * 
+     *
      * @since 2.5
      */
     protected BeanPropertyWriter() {
@@ -325,7 +325,7 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
                     base._internalSettings);
         }
         _cfgSerializationType = base._cfgSerializationType;
-        _dynamicSerializers = base._dynamicSerializers;
+        _dynamicSerializers = PropertySerializerMap.emptyForProperties();
         _suppressNulls = base._suppressNulls;
         _suppressableValue = base._suppressableValue;
         _includeInViews = base._includeInViews;
@@ -350,7 +350,7 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
                     base._internalSettings);
         }
         _cfgSerializationType = base._cfgSerializationType;
-        _dynamicSerializers = base._dynamicSerializers;
+        _dynamicSerializers = PropertySerializerMap.emptyForProperties();
         _suppressNulls = base._suppressNulls;
         _suppressableValue = base._suppressableValue;
         _includeInViews = base._includeInViews;
@@ -525,7 +525,7 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
 
     /**
      * Method for accessing value of specified internal setting.
-     * 
+     *
      * @return Value of the setting, if any; null if none.
      */
     public Object getInternalSetting(Object key) {
@@ -534,7 +534,7 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
 
     /**
      * Method for setting specific internal setting to given value
-     * 
+     *
      * @return Old value of the setting, if any (null if none)
      */
     public Object setInternalSetting(Object key, Object value) {
@@ -546,7 +546,7 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
 
     /**
      * Method for removing entry for specified internal setting.
-     * 
+     *
      * @return Existing value of the setting, if any (null if none)
      */
     public Object removeInternalSetting(Object key) {
@@ -593,7 +593,7 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
      * name).
      * <p>
      * Default implementation simply returns false.
-     * 
+     *
      * @since 2.3
      */
     public boolean isUnwrapping() {
@@ -689,6 +689,11 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
 
         // Null handling is bit different, check that first
         if (value == null) {
+            // 20-Jun-2022, tatu: Defer checking of null, see [databind#3481]
+            if((_suppressableValue != null)
+                    && prov.includeFilterSuppressNulls(_suppressableValue)) {
+                return;
+            }
             if (_nullSerializer != null) {
                 gen.writeFieldName(_name);
                 _nullSerializer.serialize(null, gen, prov);
@@ -717,7 +722,7 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
         }
         // For non-nulls: simple check for direct cycles
         if (value == bean) {
-            // three choices: exception; handled by call; or pass-through
+            // four choices: exception; handled by call; pass-through or write null
             if (_handleSelfReference(bean, gen, prov, ser)) {
                 return;
             }
@@ -734,7 +739,7 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
      * Method called to indicate that serialization of a field was omitted due
      * to filtering, in cases where backend data format does not allow basic
      * omission.
-     * 
+     *
      * @since 2.3
      */
     @Override
@@ -749,12 +754,13 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
      * Alternative to {@link #serializeAsField} that is used when a POJO is
      * serialized as JSON Array; the difference is that no field names are
      * written.
-     * 
+     *
      * @since 2.3
      */
     @Override
     public void serializeAsElement(Object bean, JsonGenerator gen,
-            SerializerProvider prov) throws Exception {
+            SerializerProvider prov) throws Exception
+    {
         // inlined 'get()'
         final Object value = (_accessorMethod == null) ? _field.get(bean)
                 : _accessorMethod.invoke(bean, (Object[]) null);
@@ -784,9 +790,8 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
                     serializeAsPlaceholder(bean, gen, prov);
                     return;
                 }
-            } else if (_suppressableValue.equals(value)) { // can NOT suppress
-                                                           // entries in tabular
-                                                           // output
+            } else if (_suppressableValue.equals(value)) {
+                // can NOT suppress entries in tabular output
                 serializeAsPlaceholder(bean, gen, prov);
                 return;
             }
@@ -809,12 +814,13 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
      * value is not to be included (is filtered out), but when we need an entry
      * so that field indexes will not be off. Typically this should output null
      * or empty String, depending on datatype.
-     * 
+     *
      * @since 2.1
      */
     @Override
     public void serializeAsPlaceholder(Object bean, JsonGenerator gen,
-            SerializerProvider prov) throws Exception {
+            SerializerProvider prov) throws Exception
+    {
         if (_nullSerializer != null) {
             _nullSerializer.serialize(null, gen, prov);
         } else {
@@ -831,7 +837,8 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
     // Also part of BeanProperty implementation
     @Override
     public void depositSchemaProperty(JsonObjectFormatVisitor v,
-            SerializerProvider provider) throws JsonMappingException {
+            SerializerProvider provider) throws JsonMappingException
+    {
         if (v != null) {
             if (isRequired()) {
                 v.property(this);
@@ -847,7 +854,7 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
      * Attempt to add the output of the given {@link BeanPropertyWriter} in the
      * given {@link ObjectNode}. Otherwise, add the default schema
      * {@link JsonNode} in place of the writer's output
-     * 
+     *
      * @param propertiesNode
      *            Node which the given property would exist within
      * @param provider
@@ -857,7 +864,8 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
     @Override
     @Deprecated
     public void depositSchemaProperty(ObjectNode propertiesNode,
-            SerializerProvider provider) throws JsonMappingException {
+            SerializerProvider provider) throws JsonMappingException
+    {
         JavaType propType = getSerializationType();
         // 03-Dec-2010, tatu: SchemaAware REALLY should use JavaType, but alas
         // it doesn't...
@@ -869,8 +877,8 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
             ser = provider.findValueSerializer(getType(), this);
         }
         boolean isOptional = !isRequired();
-        if (ser instanceof SchemaAware) {
-            schemaNode = ((SchemaAware) ser).getSchema(provider, hint,
+        if (ser instanceof com.fasterxml.jackson.databind.jsonschema.SchemaAware) {
+            schemaNode = ((com.fasterxml.jackson.databind.jsonschema.SchemaAware) ser).getSchema(provider, hint,
                     isOptional);
         } else {
             schemaNode = com.fasterxml.jackson.databind.jsonschema.JsonSchema
@@ -887,7 +895,8 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
 
     protected JsonSerializer<Object> _findAndAddDynamic(
             PropertySerializerMap map, Class<?> type,
-            SerializerProvider provider) throws JsonMappingException {
+            SerializerProvider provider) throws JsonMappingException
+    {
         PropertySerializerMap.SerializerAndMapResult result;
         if (_nonTrivialBaseType != null) {
             JavaType t = provider.constructSpecializedType(_nonTrivialBaseType,
@@ -906,14 +915,14 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
     /**
      * Method that can be used to access value of the property this Object
      * describes, from given bean instance.
-     * <p>
-     * Note: method is final as it should not need to be overridden -- rather,
-     * calling method(s) ({@link #serializeAsField}) should be overridden to
-     * change the behavior
+     *<p>
+     * NOTE: was {@code final} until Jackson 2.19
      */
-    public final Object get(Object bean) throws Exception {
-        return (_accessorMethod == null) ? _field.get(bean) : _accessorMethod
-                .invoke(bean, (Object[]) null);
+    public Object get(Object bean) throws Exception
+    {
+        return (_accessorMethod == null)
+                ? _field.get(bean)
+                : _accessorMethod.invoke(bean, (Object[]) null);
     }
 
     /**
@@ -932,21 +941,58 @@ public class BeanPropertyWriter extends PropertyWriter // which extends
      */
     protected boolean _handleSelfReference(Object bean, JsonGenerator gen,
             SerializerProvider prov, JsonSerializer<?> ser)
-            throws JsonMappingException {
-        if (prov.isEnabled(SerializationFeature.FAIL_ON_SELF_REFERENCES)
-                && !ser.usesObjectId()) {
-            // 05-Feb-2013, tatu: Usually a problem, but NOT if we are handling
-            // object id; this may be the case for BeanSerializers at least.
-            // 13-Feb-2014, tatu: another possible ok case: custom serializer
-            // (something
-            // OTHER than {@link BeanSerializerBase}
-            if (ser instanceof BeanSerializerBase) {
-                prov.reportBadDefinition(getType(), "Direct self-reference leading to cycle");
+            throws IOException
+    {
+        if (!ser.usesObjectId()) {
+            boolean writeAsNull = false;
+
+            if (prov.isEnabled(SerializationFeature.FAIL_ON_SELF_REFERENCES)) {
+                // 05-Feb-2013, tatu: Usually a problem, but NOT if we are handling
+                // object id; this may be the case for BeanSerializers at least.
+                // 13-Feb-2014, tatu: another possible ok case: custom serializer
+                // (something OTHER than {@link BeanSerializerBase}
+                if (ser instanceof BeanSerializerBase) {
+                    // 09-Jul-2025, tatu: [databind#5194] Let's suppress specific case
+                    //   of "cause" for Throwables
+                    if (_isThrowableFieldCause(prov, bean)) {
+                        writeAsNull = true;
+                    } else {
+                        prov.reportBadDefinition(getType(), "Direct self-reference leading to cycle");
+                    }
+                }
+            } else {
+                writeAsNull = prov.isEnabled(SerializationFeature.WRITE_SELF_REFERENCES_AS_NULL);
+            }
+
+            if (writeAsNull) {
+                if (_nullSerializer != null) {
+                    // 23-Oct-2019, tatu: Tricky part -- caller does not specify if it's
+                    //   "as property" (in JSON Object) or "as element" (JSON array, via
+                    //   'POJO-as-array'). And since Afterburner calls method can not easily
+                    //   start passing info either. So check generator to see...
+                    //   (note: not considering ROOT context as possibility, does not seem legal)
+                    if (!gen.getOutputContext().inArray()) {
+                        gen.writeFieldName(_name);
+                    }
+                    _nullSerializer.serialize(null, gen, prov);
+                }
+                return true;
             }
         }
         return false;
     }
 
+    // Helper method to recognize `Throwable.cause` Field, which has "this" as initialized
+    // value to mean "not set" (`Throwable.getCause()` translates this to `null`).
+    //
+    // @since 2.20
+    private boolean _isThrowableFieldCause(SerializerProvider prov, Object bean) {
+        return bean instanceof Throwable
+                && _member instanceof AnnotatedField
+                && "cause".equals(_name.getValue())
+                ;
+    }
+    
     @Override
     public String toString() {
         StringBuilder sb = new StringBuilder(40);
