@@ -4,7 +4,6 @@ import java.io.File;
 import java.io.IOException;
 import java.lang.reflect.Type;
 
-import com.fasterxml.jackson.core.JsonGenerationException;
 import com.fasterxml.jackson.core.JsonGenerator;
 import com.fasterxml.jackson.databind.JavaType;
 import com.fasterxml.jackson.databind.JsonMappingException;
@@ -16,28 +15,30 @@ import com.fasterxml.jackson.databind.jsonFormatVisitors.JsonFormatVisitorWrappe
  * For now, File objects get serialized by just outputting
  * absolute (but not canonical) name as String value
  */
+@SuppressWarnings("serial")
 public class FileSerializer
     extends StdScalarSerializer<File>
 {
     public FileSerializer() { super(File.class); }
 
     @Override
-    public void serialize(File value, JsonGenerator jgen, SerializerProvider provider)
-        throws IOException, JsonGenerationException
-    {
-        jgen.writeString(value.getAbsolutePath());
+    public void serialize(File value, JsonGenerator g, SerializerProvider provider) throws IOException {
+        g.writeString(value.getAbsolutePath());
+    }
+
+    /**
+     * @deprecated Since 2.15
+     */
+    @Deprecated
+    @Override
+    public JsonNode getSchema(SerializerProvider provider, Type typeHint) {
+        return createSchemaNode("string", true);
     }
 
-    @Override
-    public JsonNode getSchema(SerializerProvider provider, Type typeHint)
-    {
-        return createSchemaNode("string", true);
-    }
-    
     @Override
     public void acceptJsonFormatVisitor(JsonFormatVisitorWrapper visitor, JavaType typeHint)
-            throws JsonMappingException
+        throws JsonMappingException
     {
-        visitor.expectStringFormat(typeHint);
+        visitStringFormat(visitor, typeHint);
     }
 }
\ No newline at end of file
