@@ -3,19 +3,17 @@ package com.fasterxml.jackson.databind.records;
 import org.junit.jupiter.api.Test;
 
 import com.fasterxml.jackson.annotation.JsonInclude;
+
 import com.fasterxml.jackson.databind.ObjectMapper;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 
-import static com.fasterxml.jackson.databind.BaseMapTest.newJsonMapper;
-import static com.fasterxml.jackson.databind.BaseTest.a2q;
-
 /**
  * Tests to verify that `@JsonInclude` annotation works with Records on both constructor parameters and getters.
  */
-public class RecordJsonIncludeTest
+public class RecordJsonIncludeTest extends DatabindTestUtil
 {
-
     record AnnotatedParamRecordClass(
         @JsonInclude(JsonInclude.Include.NON_NULL)
         String omitFieldIfNull,
