@@ -9,8 +9,10 @@ import org.junit.jupiter.api.Test;
 
 import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonProperty;
+
 import com.fasterxml.jackson.core.JsonParser;
 import com.fasterxml.jackson.core.JsonToken;
+import com.fasterxml.jackson.core.StreamReadFeature;
 import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.cfg.CoercionAction;
 import com.fasterxml.jackson.databind.cfg.CoercionInputShape;
@@ -55,6 +57,8 @@ public class CoerceToBooleanTest
 
     private final ObjectMapper LEGACY_NONCOERCING_MAPPER = jsonMapperBuilder()
             .disable(MapperFeature.ALLOW_COERCION_OF_SCALARS)
+            // 30-May-2025, tatu: Needed after [core#1438] (clear current token on close)
+            .disable(StreamReadFeature.CLEAR_CURRENT_TOKEN_ON_CLOSE)
             .build();
 
     private final ObjectMapper MAPPER_INT_TO_EMPTY = jsonMapperBuilder()
@@ -194,14 +198,14 @@ public class CoerceToBooleanTest
         final ObjectReader r = DEFAULT_MAPPER.readerFor(BooleanPOJO.class);
 
         p = r.readValue(DOC_WITH_0);
-        assertEquals(false, p.value);
+        assertFalse(p.value);
         p = r.readValue(utf8Bytes(DOC_WITH_0));
-        assertEquals(false, p.value);
+        assertFalse(p.value);
 
         p = r.readValue(DOC_WITH_1);
-        assertEquals(true, p.value);
+        assertTrue(p.value);
         p = r.readValue(utf8Bytes(DOC_WITH_1));
-        assertEquals(true, p.value);
+        assertTrue(p.value);
     }
 
     @Test
@@ -220,12 +224,12 @@ public class CoerceToBooleanTest
 
         ab = atomicR.readValue(" 0");
         ab = atomicR.readValue(utf8Bytes(" 0"));
-        assertEquals(false, ab.get());
+        assertFalse(ab.get());
 
         ab = atomicR.readValue(" 111");
-        assertEquals(true, ab.get());
+        assertTrue(ab.get());
         ab = atomicR.readValue(utf8Bytes(" 111"));
-        assertEquals(true, ab.get());
+        assertTrue(ab.get());
     }
 
     // Test for verifying that Long values are coerced to boolean correctly as well
@@ -412,11 +416,10 @@ public class CoerceToBooleanTest
             JsonToken tokenType, String tokenValue) throws IOException
     {
         verifyException(e, "Cannot coerce ", "Cannot deserialize value of type ");
+        // 30-May-2025, tatu: [databind#5179] got access via exception now
+        assertToken(tokenType, e.getCurrentToken());
 
         JsonParser p = (JsonParser) e.getProcessor();
-
-        assertToken(tokenType, p.currentToken());
-
         final String text = p.getText();
         if (!tokenValue.equals(text)) {
             String textDesc = (text == null) ? "NULL" : q(text);
