@@ -12,6 +12,7 @@ import com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import static com.fasterxml.jackson.databind.testutil.DatabindTestUtil.a2q;
 
@@ -232,7 +233,7 @@ public class BuilderWithUnwrappedTest
         assertEquals("John", person.getName().getFirst());
         assertEquals("Doe", person.getName().getLast());
         assertEquals(30, person.getAge());
-        assertEquals(true, person.isAlive());
+        assertTrue(person.isAlive());
     }
 
     @Test
@@ -246,7 +247,7 @@ public class BuilderWithUnwrappedTest
         assertEquals("John", person.getName().getFirst());
         assertEquals("Doe", person.getName().getLast());
         assertEquals(30, person.getAge());
-        assertEquals(true, person.isAlive());
+        assertTrue(person.isAlive());
     }
 
     @Test
@@ -260,7 +261,7 @@ public class BuilderWithUnwrappedTest
         assertEquals("John", person.getName().getFirst());
         assertEquals("Doe", person.getName().getLast());
         assertEquals(30, person.getAge());
-        assertEquals(true, person.isAlive());
+        assertTrue(person.isAlive());
     }
 
     @Test
@@ -274,7 +275,7 @@ public class BuilderWithUnwrappedTest
         assertEquals("John", animal.getName().getFirst());
         assertEquals("Doe", animal.getName().getLast());
         assertEquals(30, animal.getAge());
-        assertEquals(true, animal.isAlive());
+        assertTrue(animal.isAlive());
     }
 
     @Test
@@ -288,7 +289,7 @@ public class BuilderWithUnwrappedTest
         assertEquals("John", animal.getName().getFirst());
         assertEquals("Doe", animal.getName().getLast());
         assertEquals(30, animal.getAge());
-        assertEquals(true, animal.isAlive());
+        assertTrue(animal.isAlive());
     }
 
     @Test
@@ -302,7 +303,7 @@ public class BuilderWithUnwrappedTest
         assertEquals("John", animal.getName().getFirst());
         assertEquals("Doe", animal.getName().getLast());
         assertEquals(30, animal.getAge());
-        assertEquals(true, animal.isAlive());
+        assertTrue(animal.isAlive());
     }
 
     @Test
