@@ -4,24 +4,24 @@ import java.math.BigDecimal;
 import java.math.BigInteger;
 import java.util.*;
 
-import com.fasterxml.jackson.annotation.*;
 import org.junit.jupiter.api.Test;
 
+import com.fasterxml.jackson.annotation.*;
+
 import com.fasterxml.jackson.core.JsonParser;
 import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.exc.InvalidDefinitionException;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
 import com.fasterxml.jackson.databind.util.TokenBuffer;
 
 import static org.junit.jupiter.api.Assertions.*;
 
-import static com.fasterxml.jackson.databind.testutil.DatabindTestUtil.q;
-import static com.fasterxml.jackson.databind.testutil.DatabindTestUtil.verifyException;
-
 /**
  * Unit tests for verifying that it is possible to annotate
  * various kinds of things with {@link JsonCreator} annotation.
  */
 public class TestCreators
+    extends DatabindTestUtil
 {
     /*
     /**********************************************************
@@ -109,7 +109,7 @@ public class TestCreators
     }
 
     /**
-     * Simple demonstration of INVALID construtor annotation (only
+     * Simple demonstration of INVALID constructor annotation (only
      * defining name for first arg)
      */
     static class BrokenBean {
@@ -119,33 +119,33 @@ public class TestCreators
     }
 
     /**
-     * Bean that defines both creator and factory methor as
+     * Bean that defines both creator and factory method as
      * creators. Constructors have priority; but it is possible
      * to hide it using mix-in annotations.
      */
-    static class CreatorBean
+    static class CreatorBeanWithBoth
     {
         String a;
         int x;
 
         @JsonCreator
-        protected CreatorBean(@JsonProperty("a") String paramA,
-                              @JsonProperty("x") int paramX)
+        protected CreatorBeanWithBoth(@JsonProperty("a") String paramA,
+                @JsonProperty("x") int paramX)
         {
             a = "ctor:"+paramA;
             x = 1+paramX;
         }
 
-        private CreatorBean(String a, int x, boolean dummy) {
+        private CreatorBeanWithBoth(String a, int x, boolean dummy) {
             this.a = a;
             this.x = x;
         }
 
         @JsonCreator
-        public static CreatorBean buildMeUpButterCup(@JsonProperty("a") String paramA,
-                                                     @JsonProperty("x") int paramX)
+        public static CreatorBeanWithBoth bobTheBuilder(@JsonProperty("a") String paramA,
+                @JsonProperty("x") int paramX)
         {
-            return new CreatorBean("factory:"+paramA, paramX-1, false);
+            return new CreatorBeanWithBoth("factory:"+paramA, paramX-1, false);
         }
     }
 
@@ -324,7 +324,7 @@ public class TestCreators
     /**********************************************************
      */
 
-    private final ObjectMapper MAPPER = new ObjectMapper();
+    private final ObjectMapper MAPPER = newJsonMapper();
 
     @Test
     public void testSimpleConstructor() throws Exception
@@ -420,10 +420,10 @@ public class TestCreators
     }
 
     @Test
-    public void testConstructorCreator() throws Exception
+    public void testConstructorAndFactoryCreator() throws Exception
     {
-        CreatorBean bean = MAPPER.readValue
-            ("{ \"a\" : \"xyz\", \"x\" : 12 }", CreatorBean.class);
+        CreatorBeanWithBoth bean = MAPPER.readValue
+            ("{ \"a\" : \"xyz\", \"x\" : 12 }", CreatorBeanWithBoth.class);
         assertEquals(13, bean.x);
         assertEquals("ctor:xyz", bean.a);
     }
@@ -435,7 +435,7 @@ public class TestCreators
             ("{ \"a\" : \"1\", \"b\": 2, \"c\" : true }", ConstructorAndPropsBean.class);
         assertEquals(1, bean.a);
         assertEquals(2, bean.b);
-        assertEquals(true, bean.c);
+        assertTrue(bean.c);
     }
 
     @Test
@@ -506,10 +506,11 @@ public class TestCreators
     @Test
     public void testFactoryCreatorWithMixin() throws Exception
     {
-        ObjectMapper m = new ObjectMapper();
-        m.addMixIn(CreatorBean.class, MixIn.class);
-        CreatorBean bean = m.readValue
-            ("{ \"a\" : \"xyz\", \"x\" : 12 }", CreatorBean.class);
+        ObjectMapper m = jsonMapperBuilder()
+                .addMixIn(CreatorBeanWithBoth.class, MixIn.class)
+                .build();
+        CreatorBeanWithBoth bean = m.readValue
+            ("{ \"a\" : \"xyz\", \"x\" : 12 }", CreatorBeanWithBoth.class);
         assertEquals(11, bean.x);
         assertEquals("factory:xyz", bean.a);
     }
