@@ -1,12 +1,18 @@
 package com.fasterxml.jackson.databind.exc;
 
-import com.fasterxml.jackson.databind.BaseMapTest;
-import com.fasterxml.jackson.databind.JsonMappingException;
-import com.fasterxml.jackson.databind.ObjectMapper;
-
 import java.io.IOException;
 
-public class TestExceptionHandlingWithDefaultDeserialization extends BaseMapTest
+import org.junit.jupiter.api.Test;
+
+import com.fasterxml.jackson.databind.JsonMappingException;
+import com.fasterxml.jackson.databind.ObjectMapper;
+
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.fail;
+
+import static com.fasterxml.jackson.databind.testutil.DatabindTestUtil.newJsonMapper;
+
+public class TestExceptionHandlingWithDefaultDeserialization
 {
     static class Foo {
         private Bar bar;
@@ -38,9 +44,10 @@ public class TestExceptionHandlingWithDefaultDeserialization extends BaseMapTest
         }
     }
 
-    public void testShouldThrowJsonMappingExceptionWithPathReference() throws IOException {
+    @Test
+    public void testShouldThrowExceptionWithPathReference() throws IOException {
         // given
-        ObjectMapper mapper = new ObjectMapper();
+        ObjectMapper mapper = newJsonMapper();
         String input = "{\"bar\":{\"baz\":{qux:\"quxValue\"))}";
         final String THIS = getClass().getName();
 
