@@ -2,20 +2,21 @@ package com.fasterxml.jackson.databind.introspect;
 
 import java.util.Map;
 
-import com.fasterxml.jackson.databind.*;
-import com.fasterxml.jackson.databind.introspect.BasicClassIntrospector;
-import com.fasterxml.jackson.databind.introspect.POJOPropertiesCollector;
-import com.fasterxml.jackson.databind.introspect.POJOPropertyBuilder;
+import org.junit.jupiter.api.Test;
 
-public class TestBuilderMethods extends BaseMapTest
+import com.fasterxml.jackson.databind.*;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
+
+import static org.junit.jupiter.api.Assertions.*;
+
+public class TestBuilderMethods extends DatabindTestUtil
 {
     static class SimpleBuilder
     {
         public int x;
 
-        @SuppressWarnings("hiding")
-        public SimpleBuilder withX(int x) {
-    		    this.x = x;
+        public SimpleBuilder withX(int x0) {
+    		    this.x = x0;
     		    return this;
         }
     }
@@ -27,10 +28,11 @@ public class TestBuilderMethods extends BaseMapTest
      */
 
     private final ObjectMapper mapper = new ObjectMapper();
-    
+
+    @Test
     public void testSimple()
     {
-        POJOPropertiesCollector coll = collector(SimpleBuilder.class, "with");
+        POJOPropertiesCollector coll = collector(SimpleBuilder.class);
         Map<String, POJOPropertyBuilder> props = coll.getPropertyMap();
         assertEquals(1, props.size());
         POJOPropertyBuilder prop = props.get("x");
@@ -46,12 +48,11 @@ public class TestBuilderMethods extends BaseMapTest
     /**********************************************************
      */
 
-    protected POJOPropertiesCollector collector(Class<?> cls, String prefix)
+    protected POJOPropertiesCollector collector(Class<?> cls)
     {
         BasicClassIntrospector bci = new BasicClassIntrospector();
         // no real difference between serialization, deserialization, at least here
-        return bci.collectProperties(mapper.getSerializationConfig(),
-                mapper.constructType(cls), null, false, prefix);
+        return bci.collectPropertiesWithBuilder(mapper.getSerializationConfig(),
+                mapper.constructType(cls), null, null, false);
     }
-    
 }
