@@ -1,20 +1,28 @@
 package com.fasterxml.jackson.databind.introspect;
 
+import java.lang.annotation.*;
 import java.util.Arrays;
 import java.util.List;
+import java.util.Map;
+
+import org.junit.jupiter.api.Test;
 
 import com.fasterxml.jackson.annotation.*;
 
 import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.annotation.JsonNaming;
 import com.fasterxml.jackson.databind.introspect.TestNamingStrategyCustom.PersonBean;
+import com.fasterxml.jackson.databind.json.JsonMapper;
 import com.fasterxml.jackson.databind.node.ObjectNode;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
+
+import static org.junit.jupiter.api.Assertions.*;
 
 /**
  * Unit tests to verify functioning of standard {@link PropertyNamingStrategy}
  * implementations Jackson includes out of the box.
  */
-public class TestNamingStrategyStd extends BaseMapTest
+public class TestNamingStrategyStd extends DatabindTestUtil
 {
     @JsonPropertyOrder({"www", "some_url", "some_uris"})
     static class Acronyms
@@ -22,7 +30,7 @@ public class TestNamingStrategyStd extends BaseMapTest
         public String WWW;
         public String someURL;
         public String someURIs;
-        
+
         public Acronyms() {this(null, null, null);}
         public Acronyms(String WWW, String someURL, String someURIs)
         {
@@ -31,7 +39,7 @@ public class TestNamingStrategyStd extends BaseMapTest
             this.someURIs = someURIs;
         }
     }
-    
+
     @JsonPropertyOrder({"from_user", "user", "from$user", "from7user", "_x"})
     static class UnchangedNames
     {
@@ -41,7 +49,7 @@ public class TestNamingStrategyStd extends BaseMapTest
         public String from7user;
         // Used to test "_", but it's explicitly deprecated in JDK8 so...
         public String _x;
-        
+
         public UnchangedNames() {this(null, null, null, null, null);}
         public UnchangedNames(String from_user, String _user, String from$user, String from7user, String _x)
         {
@@ -52,7 +60,7 @@ public class TestNamingStrategyStd extends BaseMapTest
             this._x = _x;
         }
     }
-    
+
     @JsonPropertyOrder({"results", "user", "__", "$_user"})
     static class OtherNonStandardNames
     {
@@ -60,7 +68,7 @@ public class TestNamingStrategyStd extends BaseMapTest
         public String _User;
         public String ___;
         public String $User;
-        
+
         public OtherNonStandardNames() {this(null, null, null, null);}
         public OtherNonStandardNames(String Results, String _User, String ___, String $User)
         {
@@ -77,7 +85,7 @@ public class TestNamingStrategyStd extends BaseMapTest
     }
 
     @JsonPropertyOrder({ "firstName", "lastName" })
-    @JsonNaming(PropertyNamingStrategy.LowerCaseStrategy.class)
+    @JsonNaming(PropertyNamingStrategies.LowerCaseStrategy.class)
     static class BoringBean {
         public String firstName = "Bob";
         public String lastName = "Burger";
@@ -86,7 +94,7 @@ public class TestNamingStrategyStd extends BaseMapTest
     public static class ClassWithObjectNodeField {
         public String id;
         public ObjectNode json;
-    }    
+    }
 
     static class ExplicitBean {
         @JsonProperty("firstName")
@@ -109,6 +117,66 @@ public class TestNamingStrategyStd extends BaseMapTest
         public FirstNameBean(String n) { firstName = n; }
     }
 
+    @Target({ElementType.FIELD, ElementType.PARAMETER, ElementType.TYPE})
+    @Retention(RetentionPolicy.RUNTIME)
+    @JacksonAnnotation
+    public @interface Name {
+        public String value();
+    }
+
+    @SuppressWarnings("serial")
+    static class ParamNameIntrospector extends JacksonAnnotationIntrospector
+    {
+        @Override
+        public String findImplicitPropertyName(AnnotatedMember param) {
+            Name nameAnn = param.getAnnotation(Name.class);
+            if (nameAnn != null) {
+                return nameAnn.value();
+            }
+            return super.findImplicitPropertyName(param);
+        }
+    }
+
+    @JsonNaming(PropertyNamingStrategies.SnakeCaseStrategy.class)
+    static class SnakeNameBean {
+        String _id, _fullName;
+
+        @JsonCreator
+        protected SnakeNameBean(@Name("id") String id,
+                @Name("fullName") String fn) {
+            _id = id;
+            _fullName = fn;
+        }
+    }
+
+    @JsonNaming(PropertyNamingStrategies.SnakeCaseStrategy.class)
+    static class Value3368 {
+        private String timeZone;
+        private String utcZone;
+
+        @JsonProperty("time_zone")
+        void unpackTimeZone(Map<String, String> timeZone) {
+            this.setTimeZone(timeZone.get("name"));
+            this.setUtcZone(timeZone.get("utc_zone"));
+        }
+
+        public String getTimeZone() {
+            return this.timeZone;
+        }
+
+        public String getUtcZone() {
+            return this.utcZone;
+        }
+
+        public void setTimeZone(String timeZone) {
+            this.timeZone = timeZone;
+        }
+
+        public void setUtcZone(String utcZone) {
+            this.utcZone = utcZone;
+        }
+    }
+
     /*
     /**********************************************************
     /* Set up
@@ -170,18 +238,76 @@ public class TestNamingStrategyStd extends BaseMapTest
                 {"uId", "u_id" },
                 // [databind#2267]
                 {"xCoordinate", "x_coordinate" },
+                // [databind#4409]
+                {"RGBA", "rgba"},
+                {"RGBa", "rgba"},
     });
 
-    private ObjectMapper _lcWithUndescoreMapper;
-    
-    @Override
-    public void setUp() throws Exception
-    {
-        super.setUp();
-        _lcWithUndescoreMapper = new ObjectMapper();
-        _lcWithUndescoreMapper.setPropertyNamingStrategy(PropertyNamingStrategy.SNAKE_CASE);
-    }
-    
+    final static List<Object[]> UPPER_SNAKE_CASE_NAME_TRANSLATIONS = Arrays.asList(new Object[][] {
+        {null, null},
+        {"", ""},
+        {"a", "A"},
+        {"abc", "ABC"},
+        {"1", "1"},
+        {"123", "123"},
+        {"1a", "1A"},
+        {"a1", "A1"},
+        {"$", "$"},
+        {"$a", "$A"},
+        {"a$", "A$"},
+        {"$_a", "$_A"},
+        {"a_$", "A_$"},
+        {"a$a", "A$A"},
+        {"$A", "$_A"},
+        {"$_A", "$_A"},
+        {"_", "_"},
+        {"__", "_"},
+        {"___", "__"},
+        {"A", "A"},
+        {"A1", "A1"},
+        {"1A", "1_A"},
+        {"_a", "A"},
+        {"_A", "A"},
+        {"a_a", "A_A"},
+        {"a_A", "A_A"},
+        {"A_A", "A_A"},
+        {"A_a", "A_A"},
+        {"WWW", "WWW"},
+        {"someURI", "SOME_URI"},
+        {"someURIs", "SOME_URIS"},
+        {"Results", "RESULTS"},
+        {"_Results", "RESULTS"},
+        {"_results", "RESULTS"},
+        {"__results", "_RESULTS"},
+        {"__Results", "_RESULTS"},
+        {"___results", "__RESULTS"},
+        {"___Results", "__RESULTS"},
+        {"userName", "USER_NAME"},
+        {"user_name", "USER_NAME"},
+        {"user__name", "USER__NAME"},
+        {"UserName", "USER_NAME"},
+        {"User_Name", "USER_NAME"},
+        {"User__Name", "USER__NAME"},
+        {"_user_name", "USER_NAME"},
+        {"_UserName", "USER_NAME"},
+        {"_User_Name", "USER_NAME"},
+        {"USER_NAME", "USER_NAME"},
+        {"_Bars", "BARS" },
+        {"usId", "US_ID" },
+        {"uId", "U_ID" },
+        {"xCoordinate", "X_COORDINATE" },
+    });
+
+    private final ObjectMapper VANILLA_MAPPER = newJsonMapper();
+
+    private final ObjectMapper _lcWithUnderscoreMapper = JsonMapper.builder()
+            .propertyNamingStrategy(PropertyNamingStrategies.SNAKE_CASE)
+            .build();
+
+    private final ObjectMapper _ucWithUnderscoreMapper = JsonMapper.builder()
+        .propertyNamingStrategy(PropertyNamingStrategies.UPPER_SNAKE_CASE)
+        .build();
+
     /*
     /**********************************************************
     /* Test methods for SNAKE_CASE
@@ -189,67 +315,72 @@ public class TestNamingStrategyStd extends BaseMapTest
      */
 
     /**
-     * Unit test to verify translations of 
-     * {@link PropertyNamingStrategy#SNAKE_CASE} 
+     * Unit test to verify translations of
+     * {@link PropertyNamingStrategies#SNAKE_CASE}
      * outside the context of an ObjectMapper.
      */
+    @Test
     public void testLowerCaseStrategyStandAlone()
     {
         for (Object[] pair : SNAKE_CASE_NAME_TRANSLATIONS) {
-            String translatedJavaName = PropertyNamingStrategy.SNAKE_CASE.nameForField(null, null,
+            String translatedJavaName = PropertyNamingStrategies.SNAKE_CASE.nameForField(null, null,
                     (String) pair[0]);
             assertEquals((String) pair[1], translatedJavaName);
         }
     }
 
+    @Test
     public void testLowerCaseTranslations() throws Exception
     {
         // First serialize
-        String json = _lcWithUndescoreMapper.writeValueAsString(new PersonBean("Joe", "Sixpack", 42));
+        String json = _lcWithUnderscoreMapper.writeValueAsString(new PersonBean("Joe", "Sixpack", 42));
         assertEquals("{\"first_name\":\"Joe\",\"last_name\":\"Sixpack\",\"age\":42}", json);
-        
+
         // then deserialize
-        PersonBean result = _lcWithUndescoreMapper.readValue(json, PersonBean.class);
+        PersonBean result = _lcWithUnderscoreMapper.readValue(json, PersonBean.class);
         assertEquals("Joe", result.firstName);
         assertEquals("Sixpack", result.lastName);
         assertEquals(42, result.age);
     }
-    
+
+    @Test
     public void testLowerCaseAcronymsTranslations() throws Exception
     {
         // First serialize
-        String json = _lcWithUndescoreMapper.writeValueAsString(new Acronyms("world wide web", "http://jackson.codehaus.org", "/path1/,/path2/"));
+        String json = _lcWithUnderscoreMapper.writeValueAsString(new Acronyms("world wide web", "http://jackson.codehaus.org", "/path1/,/path2/"));
         assertEquals("{\"www\":\"world wide web\",\"some_url\":\"http://jackson.codehaus.org\",\"some_uris\":\"/path1/,/path2/\"}", json);
-        
+
         // then deserialize
-        Acronyms result = _lcWithUndescoreMapper.readValue(json, Acronyms.class);
+        Acronyms result = _lcWithUnderscoreMapper.readValue(json, Acronyms.class);
         assertEquals("world wide web", result.WWW);
         assertEquals("http://jackson.codehaus.org", result.someURL);
         assertEquals("/path1/,/path2/", result.someURIs);
     }
 
+    @Test
     public void testLowerCaseOtherNonStandardNamesTranslations() throws Exception
     {
         // First serialize
-        String json = _lcWithUndescoreMapper.writeValueAsString(new OtherNonStandardNames("Results", "_User", "___", "$User"));
+        String json = _lcWithUnderscoreMapper.writeValueAsString(new OtherNonStandardNames("Results", "_User", "___", "$User"));
         assertEquals("{\"results\":\"Results\",\"user\":\"_User\",\"__\":\"___\",\"$_user\":\"$User\"}", json);
-        
+
         // then deserialize
-        OtherNonStandardNames result = _lcWithUndescoreMapper.readValue(json, OtherNonStandardNames.class);
+        OtherNonStandardNames result = _lcWithUnderscoreMapper.readValue(json, OtherNonStandardNames.class);
         assertEquals("Results", result.Results);
         assertEquals("_User", result._User);
         assertEquals("___", result.___);
         assertEquals("$User", result.$User);
     }
 
+    @Test
     public void testLowerCaseUnchangedNames() throws Exception
     {
         // First serialize
-        String json = _lcWithUndescoreMapper.writeValueAsString(new UnchangedNames("from_user", "_user", "from$user", "from7user", "_x"));
+        String json = _lcWithUnderscoreMapper.writeValueAsString(new UnchangedNames("from_user", "_user", "from$user", "from7user", "_x"));
         assertEquals("{\"from_user\":\"from_user\",\"user\":\"_user\",\"from$user\":\"from$user\",\"from7user\":\"from7user\",\"x\":\"_x\"}", json);
-        
+
         // then deserialize
-        UnchangedNames result = _lcWithUndescoreMapper.readValue(json, UnchangedNames.class);
+        UnchangedNames result = _lcWithUnderscoreMapper.readValue(json, UnchangedNames.class);
         assertEquals("from_user", result.from_user);
         assertEquals("_user", result._user);
         assertEquals("from$user", result.from$user);
@@ -257,6 +388,53 @@ public class TestNamingStrategyStd extends BaseMapTest
         assertEquals("_x", result._x);
     }
 
+    // [databind#3368]
+    @Test
+    public void testSnakeCase3368() throws Exception
+    {
+        String test = "    {\n" +
+"      \"time_zone\": {\n" +
+"        \"name\": \"XXX\",\n" +
+"        \"utc_zone\": \"ZZZ\"\n" +
+"      }\n" +
+"    }";
+        Value3368 res = sharedMapper().readerFor(Value3368.class).readValue(test);
+        assertEquals("XXX", res.getTimeZone());
+        assertEquals("ZZZ", res.getUtcZone());
+    }
+
+    /*
+    /**********************************************************
+    /* Test methods for UPPER_SNAKE_CASE
+    /**********************************************************
+     */
+
+    @Test
+    public void testUpperSnakeCaseStrategyStandAlone()
+    {
+        for (Object[] pair : UPPER_SNAKE_CASE_NAME_TRANSLATIONS) {
+            String translatedJavaName = PropertyNamingStrategies.UPPER_SNAKE_CASE
+                .nameForField(null, null, (String) pair[0]);
+            assertEquals((String) pair[1], translatedJavaName);
+        }
+    }
+
+    @Test
+    public void testUpperSnakeCaseTranslations() throws Exception
+    {
+        // First serialize
+        String json = _ucWithUnderscoreMapper
+            .writeValueAsString(new PersonBean("Joe", "Sixpack", 42));
+        assertEquals("{\"FIRST_NAME\":\"Joe\",\"LAST_NAME\":\"Sixpack\",\"AGE\":42}", json);
+
+        // then deserialize
+        PersonBean result = _ucWithUnderscoreMapper.readValue(json, PersonBean.class);
+        assertEquals("Joe", result.firstName);
+        assertEquals("Sixpack", result.lastName);
+        assertEquals(42, result.age);
+    }
+
+
     /*
     /**********************************************************
     /* Test methods for UPPER_CAMEL_CASE
@@ -264,28 +442,30 @@ public class TestNamingStrategyStd extends BaseMapTest
      */
 
     /**
-     * Unit test to verify translations of 
-     * {@link PropertyNamingStrategy#UPPER_CAMEL_CASE } 
+     * Unit test to verify translations of
+     * {@link PropertyNamingStrategies#UPPER_CAMEL_CASE }
      * outside the context of an ObjectMapper.
      */
+    @Test
     public void testPascalCaseStandAlone()
     {
-        assertEquals("UserName", PropertyNamingStrategy.UPPER_CAMEL_CASE.nameForField(null, null, "userName"));
-        assertEquals("User", PropertyNamingStrategy.UPPER_CAMEL_CASE.nameForField(null, null, "User"));
-        assertEquals("User", PropertyNamingStrategy.UPPER_CAMEL_CASE.nameForField(null, null, "user"));
-        assertEquals("X", PropertyNamingStrategy.UPPER_CAMEL_CASE.nameForField(null, null, "x"));
+        assertEquals("UserName", PropertyNamingStrategies.UPPER_CAMEL_CASE.nameForField(null, null, "userName"));
+        assertEquals("User", PropertyNamingStrategies.UPPER_CAMEL_CASE.nameForField(null, null, "User"));
+        assertEquals("User", PropertyNamingStrategies.UPPER_CAMEL_CASE.nameForField(null, null, "user"));
+        assertEquals("X", PropertyNamingStrategies.UPPER_CAMEL_CASE.nameForField(null, null, "x"));
 
-        assertEquals("BADPublicName", PropertyNamingStrategy.UPPER_CAMEL_CASE.nameForField(null, null, "bADPublicName"));
-        assertEquals("BADPublicName", PropertyNamingStrategy.UPPER_CAMEL_CASE.nameForGetterMethod(null, null, "bADPublicName"));
+        assertEquals("BADPublicName", PropertyNamingStrategies.UPPER_CAMEL_CASE.nameForField(null, null, "bADPublicName"));
+        assertEquals("BADPublicName", PropertyNamingStrategies.UPPER_CAMEL_CASE.nameForGetterMethod(null, null, "bADPublicName"));
     }
 
     // [databind#428]
+    @Test
     public void testIssue428PascalWithOverrides() throws Exception
     {
         String json = new ObjectMapper()
-                .setPropertyNamingStrategy(PropertyNamingStrategy.UPPER_CAMEL_CASE)
+                .setPropertyNamingStrategy(PropertyNamingStrategies.UPPER_CAMEL_CASE)
                 .writeValueAsString(new Bean428());
-        if (!json.contains(quote("fooBar"))) {
+        if (!json.contains(q("fooBar"))) {
             fail("Should use name 'fooBar', does not: "+json);
         }
     }
@@ -297,12 +477,13 @@ public class TestNamingStrategyStd extends BaseMapTest
      */
 
     // For [databind#461]
+    @Test
     public void testSimpleLowerCase() throws Exception
     {
         final BoringBean input = new BoringBean();
-        ObjectMapper m = objectMapper();
+        ObjectMapper m = newJsonMapper();
 
-        assertEquals(aposToQuotes("{'firstname':'Bob','lastname':'Burger'}"),
+        assertEquals(a2q("{'firstname':'Bob','lastname':'Burger'}"),
                 m.writeValueAsString(input));
     }
 
@@ -311,63 +492,68 @@ public class TestNamingStrategyStd extends BaseMapTest
     /* Test methods for KEBAB_CASE
     /**********************************************************
      */
-    
+
+    @Test
     public void testKebabCaseStrategyStandAlone()
     {
         assertEquals("some-value",
-                PropertyNamingStrategy.KEBAB_CASE.nameForField(null, null, "someValue"));
+                PropertyNamingStrategies.KEBAB_CASE.nameForField(null, null, "someValue"));
         assertEquals("some-value",
-                PropertyNamingStrategy.KEBAB_CASE.nameForField(null, null, "SomeValue"));
+                PropertyNamingStrategies.KEBAB_CASE.nameForField(null, null, "SomeValue"));
         assertEquals("url",
-                PropertyNamingStrategy.KEBAB_CASE.nameForField(null, null, "URL"));
+                PropertyNamingStrategies.KEBAB_CASE.nameForField(null, null, "URL"));
         assertEquals("url-stuff",
-                PropertyNamingStrategy.KEBAB_CASE.nameForField(null, null, "URLStuff"));
+                PropertyNamingStrategies.KEBAB_CASE.nameForField(null, null, "URLStuff"));
         assertEquals("some-url-stuff",
-                PropertyNamingStrategy.KEBAB_CASE.nameForField(null, null, "SomeURLStuff"));
+                PropertyNamingStrategies.KEBAB_CASE.nameForField(null, null, "SomeURLStuff"));
     }
-    
+
+    @Test
     public void testSimpleKebabCase() throws Exception
     {
         final FirstNameBean input = new FirstNameBean("Bob");
         ObjectMapper m = new ObjectMapper()
-                .setPropertyNamingStrategy(PropertyNamingStrategy.KEBAB_CASE);
+                .setPropertyNamingStrategy(PropertyNamingStrategies.KEBAB_CASE);
 
-        assertEquals(aposToQuotes("{'first-name':'Bob'}"), m.writeValueAsString(input));
+        assertEquals(a2q("{'first-name':'Bob'}"), m.writeValueAsString(input));
 
-        FirstNameBean result = m.readValue(aposToQuotes("{'first-name':'Billy'}"),
+        FirstNameBean result = m.readValue(a2q("{'first-name':'Billy'}"),
                 FirstNameBean.class);
         assertEquals("Billy", result.firstName);
     }
+
     /*
     /**********************************************************
     /* Test methods for LOWER_DOT_CASE
     /**********************************************************
      */
 
+    @Test
     public void testLowerCaseWithDotsStrategyStandAlone()
     {
         assertEquals("some.value",
-            PropertyNamingStrategy.LOWER_DOT_CASE.nameForField(null, null, "someValue"));
+                PropertyNamingStrategies.LOWER_DOT_CASE.nameForField(null, null, "someValue"));
         assertEquals("some.value",
-            PropertyNamingStrategy.LOWER_DOT_CASE.nameForField(null, null, "SomeValue"));
+                PropertyNamingStrategies.LOWER_DOT_CASE.nameForField(null, null, "SomeValue"));
         assertEquals("url",
-            PropertyNamingStrategy.LOWER_DOT_CASE.nameForField(null, null, "URL"));
+                PropertyNamingStrategies.LOWER_DOT_CASE.nameForField(null, null, "URL"));
         assertEquals("url.stuff",
-            PropertyNamingStrategy.LOWER_DOT_CASE.nameForField(null, null, "URLStuff"));
+                PropertyNamingStrategies.LOWER_DOT_CASE.nameForField(null, null, "URLStuff"));
         assertEquals("some.url.stuff",
-            PropertyNamingStrategy.LOWER_DOT_CASE.nameForField(null, null, "SomeURLStuff"));
+                PropertyNamingStrategies.LOWER_DOT_CASE.nameForField(null, null, "SomeURLStuff"));
     }
 
+    @Test
     public void testSimpleLowerCaseWithDots() throws Exception
     {
         final ObjectMapper m = jsonMapperBuilder()
-            .propertyNamingStrategy(PropertyNamingStrategy.LOWER_DOT_CASE)
+            .propertyNamingStrategy(PropertyNamingStrategies.LOWER_DOT_CASE)
             .build();
 
         final FirstNameBean input = new FirstNameBean("Bob");
-        assertEquals(aposToQuotes("{'first.name':'Bob'}"), m.writeValueAsString(input));
+        assertEquals(a2q("{'first.name':'Bob'}"), m.writeValueAsString(input));
 
-        FirstNameBean result = m.readValue(aposToQuotes("{'first.name':'Billy'}"),
+        FirstNameBean result = m.readValue(a2q("{'first.name':'Billy'}"),
                 FirstNameBean.class);
         assertEquals("Billy", result.firstName);
     }
@@ -377,14 +563,15 @@ public class TestNamingStrategyStd extends BaseMapTest
     /* Test methods, other
     /**********************************************************
      */
-    
+
     /**
      * Test [databind#815], problems with ObjectNode, naming strategy
      */
+    @Test
     public void testNamingWithObjectNode() throws Exception
     {
         ObjectMapper m = new ObjectMapper()
-            .setPropertyNamingStrategy(PropertyNamingStrategy.LOWER_CASE);
+            .setPropertyNamingStrategy(PropertyNamingStrategies.LOWER_CASE);
         ClassWithObjectNodeField result =
             m.readValue(
                 "{ \"id\": \"1\", \"json\": { \"foo\": \"bar\", \"baz\": \"bing\" } }",
@@ -396,28 +583,29 @@ public class TestNamingStrategyStd extends BaseMapTest
         assertEquals("bing", result.json.path("baz").asText());
     }
 
+    @Test
     public void testExplicitRename() throws Exception
     {
         ObjectMapper m = jsonMapperBuilder()
-                .propertyNamingStrategy(PropertyNamingStrategy.SNAKE_CASE)
+                .propertyNamingStrategy(PropertyNamingStrategies.SNAKE_CASE)
                 .enable(MapperFeature.SORT_PROPERTIES_ALPHABETICALLY)
                 .build();
         // by default, renaming will not take place on explicitly named fields
-        assertEquals(aposToQuotes("{'firstName':'Peter','lastName':'Venkman','user_age':'35'}"),
+        assertEquals(a2q("{'firstName':'Peter','lastName':'Venkman','user_age':'35'}"),
                 m.writeValueAsString(new ExplicitBean()));
 
         m = jsonMapperBuilder()
-                .propertyNamingStrategy(PropertyNamingStrategy.SNAKE_CASE)
+                .propertyNamingStrategy(PropertyNamingStrategies.SNAKE_CASE)
                 .enable(MapperFeature.SORT_PROPERTIES_ALPHABETICALLY)
                 .enable(MapperFeature.ALLOW_EXPLICIT_PROPERTY_RENAMING)
                 .build();
         // w/ feature enabled, ALL property names should get re-written
-        assertEquals(aposToQuotes("{'first_name':'Peter','last_name':'Venkman','user_age':'35'}"),
+        assertEquals(a2q("{'first_name':'Peter','last_name':'Venkman','user_age':'35'}"),
                 m.writeValueAsString(new ExplicitBean()));
 
         // test deserialization as well
         ExplicitBean bean =
-                m.readValue(aposToQuotes("{'first_name':'Egon','last_name':'Spengler','user_age':'32'}"),
+                m.readValue(a2q("{'first_name':'Egon','last_name':'Spengler','user_age':'32'}"),
                         ExplicitBean.class);
 
         assertNotNull(bean);
@@ -427,10 +615,44 @@ public class TestNamingStrategyStd extends BaseMapTest
     }
 
     // Also verify that "no naming strategy" should be ok
+    @Test
     public void testExplicitNoNaming() throws Exception
     {
-        ObjectMapper mapper = objectMapper();
-        String json = mapper.writeValueAsString(new DefaultNaming());
-        assertEquals(aposToQuotes("{'someValue':3}"), json);
+        assertEquals(a2q("{'someValue':3}"),
+                VANILLA_MAPPER.writeValueAsString(new DefaultNaming()));
+    }
+
+    // Try to reproduce [databind#3102] but with regular POJO. Oddly,
+    // does not actually fail.
+    @Test
+    public void testNamingViaConstructorParams() throws Exception
+    {
+        ObjectMapper mapper = jsonMapperBuilder()
+                .annotationIntrospector(new ParamNameIntrospector())
+                .build();
+        SnakeNameBean value = mapper.readValue(
+                a2q("{'id':'foobar', 'full_name' : 'Foo Bar'}"),
+                SnakeNameBean.class);
+        assertEquals("foobar", value._id);
+        assertEquals("Foo Bar", value._fullName);
+    }
+
+    @Test
+    public void testNamingStrategiesHandlingNullAndEmpty() {
+        PropertyNamingStrategies.NamingBase[] strategies = new PropertyNamingStrategies.NamingBase[]{
+            PropertyNamingStrategies.UpperSnakeCaseStrategy.INSTANCE,
+            PropertyNamingStrategies.LowerCaseStrategy.INSTANCE,
+            PropertyNamingStrategies.SnakeCaseStrategy.INSTANCE,
+            PropertyNamingStrategies.LowerCamelCaseStrategy.INSTANCE,
+            PropertyNamingStrategies.UpperCamelCaseStrategy.INSTANCE,
+            PropertyNamingStrategies.LowerDotCaseStrategy.INSTANCE,
+            PropertyNamingStrategies.KebabCaseStrategy.INSTANCE
+        };
+
+        for (PropertyNamingStrategies.NamingBase namingStrategy : strategies) {
+            assertNull(namingStrategy.translate(null));
+            assertEquals("", namingStrategy.translate(""));
+            assertEquals(" ", namingStrategy.translate(" "));
+        }
     }
 }
