@@ -2,15 +2,18 @@ package com.fasterxml.jackson.databind.jsonschema;
 
 import java.util.*;
 
+import org.junit.jupiter.api.Test;
+
 import com.fasterxml.jackson.databind.*;
-import com.fasterxml.jackson.databind.jsonschema.JsonSchema;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
+
+import static org.junit.jupiter.api.Assertions.*;
 
 /**
  * Trivial test to ensure <code>JsonSchema</code> can be also deserialized
  */
-@SuppressWarnings("deprecation")
 public class TestReadJsonSchema
-    extends com.fasterxml.jackson.databind.BaseMapTest
+    extends DatabindTestUtil
 {
     enum SchemaEnum { YES, NO; }
 
@@ -48,6 +51,8 @@ public class TestReadJsonSchema
      * Verifies that a simple schema that is serialized can be
      * deserialized back to equal schema instance
      */
+    @SuppressWarnings("deprecation")
+    @Test
     public void testDeserializeSimple() throws Exception
     {
         ObjectMapper mapper = new ObjectMapper();
@@ -57,6 +62,6 @@ public class TestReadJsonSchema
         String schemaStr = mapper.writeValueAsString(schema);
         assertNotNull(schemaStr);
         JsonSchema result = mapper.readValue(schemaStr, JsonSchema.class);
-        assertEquals("Trying to read from '"+schemaStr+"'", schema, result);
+        assertEquals(schema, result, "Trying to read from '"+schemaStr+"'");
     }
 }
