@@ -1,16 +1,21 @@
 package com.fasterxml.jackson.databind.jsontype;
 
-import com.fasterxml.jackson.annotation.JsonPropertyOrder;
-import com.fasterxml.jackson.annotation.JsonSubTypes;
-import com.fasterxml.jackson.annotation.JsonTypeId;
-import com.fasterxml.jackson.annotation.JsonTypeInfo;
-import com.fasterxml.jackson.annotation.JsonTypeName;
+import org.junit.jupiter.api.Test;
+
+import com.fasterxml.jackson.annotation.*;
+import com.fasterxml.jackson.annotation.JsonTypeInfo.As;
+import com.fasterxml.jackson.annotation.JsonTypeInfo.Id;
+
 import com.fasterxml.jackson.databind.*;
+import com.fasterxml.jackson.databind.exc.InvalidDefinitionException;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
+
+import static org.junit.jupiter.api.Assertions.*;
 
 /**
- * Tests to verify [JACKSON-437], [JACKSON-762]
+ * Tests to verify that Type Id may be exposed during deserialization,
  */
-public class TestVisibleTypeId extends BaseMapTest
+public class TestVisibleTypeId extends DatabindTestUtil
 {
     // type id as property, exposed
     @JsonTypeInfo(use=JsonTypeInfo.Id.NAME, include=JsonTypeInfo.As.PROPERTY,
@@ -48,13 +53,6 @@ public class TestVisibleTypeId extends BaseMapTest
         public void setType(String t) { type = t; }
     }
 
-    // as external id, bit trickier
-    static class ExternalIdWrapper {
-        @JsonTypeInfo(use=JsonTypeInfo.Id.NAME, include=JsonTypeInfo.As.EXTERNAL_PROPERTY,
-                property="type", visible=true)
-        public ExternalIdBean bean = new ExternalIdBean();
-    }
-    
     @JsonTypeName("ExternalType")
     static class ExternalIdBean {
         public int a = 2;
@@ -65,7 +63,7 @@ public class TestVisibleTypeId extends BaseMapTest
     }
 
     // // // [JACKSON-762]: type id from property
-    
+
     @JsonTypeInfo(use=JsonTypeInfo.Id.NAME, include=JsonTypeInfo.As.PROPERTY,
             property="type")
     static class TypeIdFromFieldProperty {
@@ -87,7 +85,7 @@ public class TestVisibleTypeId extends BaseMapTest
             property="type")
     static class TypeIdFromMethodObject {
         public int a = 3;
-        
+
         @JsonTypeId
         public String getType() { return "SomeType"; }
     }
@@ -101,7 +99,7 @@ public class TestVisibleTypeId extends BaseMapTest
     static class ExternalIdBean2 {
         public int a = 2;
 
-        /* Type id property itself can not be external, as it is conceptually
+        /* Type id property itself cannot be external, as it is conceptually
          * part of the bean for which info is written:
          */
         @JsonTypeId
@@ -130,10 +128,36 @@ public class TestVisibleTypeId extends BaseMapTest
     {
         @Override
         public String getName() { return "bob"; }
-        
+
         public int age = 41;
     }
-    
+
+    // [databind#408]
+    static class ExternalBeanWithId
+    {
+        protected String _type;
+
+        @JsonTypeInfo(use=Id.NAME, include=As.EXTERNAL_PROPERTY, property="type", visible=true)
+        public ValueBean bean;
+
+        public ExternalBeanWithId() { }
+        public ExternalBeanWithId(int v) {
+            bean = new ValueBean(v);
+        }
+
+        public void setType(String t) {
+            _type = t;
+        }
+    }
+
+    @JsonTypeName("vbean")
+    static class ValueBean {
+        public int value;
+
+        public ValueBean() { }
+        public ValueBean(int v) { value = v; }
+    }
+
     /*
     /**********************************************************
     /* Unit tests, success
@@ -141,7 +165,8 @@ public class TestVisibleTypeId extends BaseMapTest
      */
 
     private final ObjectMapper MAPPER = new ObjectMapper();
-    
+
+    @Test
     public void testVisibleWithProperty() throws Exception
     {
         String json = MAPPER.writeValueAsString(new PropertyBean());
@@ -157,6 +182,7 @@ public class TestVisibleTypeId extends BaseMapTest
         assertEquals("BaseType", result.type);
     }
 
+    @Test
     public void testVisibleWithWrapperArray() throws Exception
     {
         String json = MAPPER.writeValueAsString(new WrapperArrayBean());
@@ -168,6 +194,7 @@ public class TestVisibleTypeId extends BaseMapTest
         assertEquals(1, result.a);
     }
 
+    @Test
     public void testVisibleWithWrapperObject() throws Exception
     {
         String json = MAPPER.writeValueAsString(new WrapperObjectBean());
@@ -177,66 +204,77 @@ public class TestVisibleTypeId extends BaseMapTest
         assertEquals("ObjectType", result.type);
     }
 
-    public void testVisibleWithExternalId() throws Exception
-    {
-        String json = MAPPER.writeValueAsString(new ExternalIdWrapper());
-        // but then expect to read it back
-        ExternalIdWrapper result = MAPPER.readValue(json, ExternalIdWrapper.class);
-        assertEquals("ExternalType", result.bean.type);
-        assertEquals(2, result.bean.a);
-    }
-
-    // [JACKSON-762]
-
+    @Test
     public void testTypeIdFromProperty() throws Exception
     {
         assertEquals("{\"type\":\"SomeType\",\"a\":3}",
                 MAPPER.writeValueAsString(new TypeIdFromFieldProperty()));
     }
 
+    @Test
     public void testTypeIdFromArray() throws Exception
     {
         assertEquals("[\"SomeType\",{\"a\":3}]",
                 MAPPER.writeValueAsString(new TypeIdFromFieldArray()));
     }
 
+    @Test
     public void testTypeIdFromObject() throws Exception
     {
         assertEquals("{\"SomeType\":{\"a\":3}}",
                 MAPPER.writeValueAsString(new TypeIdFromMethodObject()));
     }
 
+    @Test
     public void testTypeIdFromExternal() throws Exception
     {
         String json = MAPPER.writeValueAsString(new ExternalIdWrapper2());
         // Implementation detail: type id written AFTER value, due to constraints
         assertEquals("{\"bean\":{\"a\":2},\"type\":\"SomeType\"}", json);
-        
+
     }
-    
+
+    @Test
     public void testIssue263() throws Exception
     {
         // first, serialize:
         assertEquals("{\"name\":\"bob\",\"age\":41}", MAPPER.writeValueAsString(new I263Impl()));
-        
+
         // then bring back:
         I263Base result = MAPPER.readValue("{\"age\":19,\"name\":\"bob\"}", I263Base.class);
         assertTrue(result instanceof I263Impl);
         assertEquals(19, ((I263Impl) result).age);
     }
-    
+
+    // [databind#408]
+    /* NOTE: Handling changed between 2.4 and 2.5; earlier, type id was 'injected'
+     *  inside POJO; but with 2.5 this was fixed so it would remain outside, similar
+     *  to how JSON structure is.
+     */
+    @Test
+    public void testVisibleTypeId408() throws Exception
+    {
+        String json = MAPPER.writeValueAsString(new ExternalBeanWithId(3));
+        ExternalBeanWithId result = MAPPER.readValue(json, ExternalBeanWithId.class);
+        assertNotNull(result);
+        assertNotNull(result.bean);
+        assertEquals(3, result.bean.value);
+        assertEquals("vbean", result._type);
+    }
+
     /*
     /**********************************************************
     /* Unit tests, fails
     /**********************************************************
      */
 
+    @Test
     public void testInvalidMultipleTypeIds() throws Exception
     {
         try {
             MAPPER.writeValueAsString(new MultipleIds());
             fail("Should have failed");
-        } catch (JsonMappingException e) {
+        } catch (InvalidDefinitionException e) {
             verifyException(e, "multiple type ids");
         }
     }
