@@ -2,12 +2,17 @@ package com.fasterxml.jackson.databind.mixins;
 
 import java.io.*;
 
+import org.junit.jupiter.api.Test;
+
 import com.fasterxml.jackson.annotation.*;
 
 import com.fasterxml.jackson.databind.*;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
+
+import static org.junit.jupiter.api.Assertions.*;
 
 public class TestMixinDeserForCreators
-    extends BaseMapTest
+    extends DatabindTestUtil
 {
     /*
     /**********************************************************
@@ -68,7 +73,7 @@ public class TestMixinDeserForCreators
         private StringWrapper(String s, boolean foo) { _value = s; }
 
         @SuppressWarnings("unused")
-		private static StringWrapper create(String str) {
+        private static StringWrapper create(String str) {
             return new StringWrapper(str, false);
         }
     }
@@ -77,12 +82,39 @@ public class TestMixinDeserForCreators
         @JsonCreator static StringWrapper create(String str) { return null; }
     }
 
+    // [databind#2020]
+    static class Pair2020 {
+        final int x, y;
+
+        private Pair2020(int x0, int y0) {
+            x = x0;
+            y = y0;
+        }
+
+        static Pair2020 with(Object x0, Object y0) {
+            return new Pair2020(((Number) x0).intValue(),
+                    ((Number) y0).intValue());
+        }
+    }
+
+    @JsonIgnoreProperties("size")
+    static class MyPairMixIn8 { // with and without <Long, String>
+         @JsonCreator
+         static TestMixinDeserForCreators.Pair2020 with(@JsonProperty("value0") Object value0,
+                   @JsonProperty("value1") Object value1)
+         {
+             // body does not matter, only signature
+             return null;
+         }
+    }
+
     /*
     /**********************************************************
     /* Unit tests
     /**********************************************************
      */
 
+    @Test
     public void testForConstructor() throws IOException
     {
         ObjectMapper m = new ObjectMapper();
@@ -91,6 +123,7 @@ public class TestMixinDeserForCreators
         assertEquals("?...", result._a);
     }
 
+    @Test
     public void testForFactoryAndCtor() throws IOException
     {
         ObjectMapper m = new ObjectMapper();
@@ -107,11 +140,25 @@ public class TestMixinDeserForCreators
         assertEquals("stringX", result._a);
     }
 
-    public void testFactoryMixIn() throws IOException
+    @Test
+    public void testFactoryDelegateMixIn() throws IOException
     {
         ObjectMapper m = new ObjectMapper();
         m.addMixIn(StringWrapper.class, StringWrapperMixIn.class);
         StringWrapper result = m.readValue("\"a\"", StringWrapper.class);
         assertEquals("a", result._value);
     }
+
+    // [databind#2020]
+    @Test
+    public void testFactoryPropertyMixin() throws Exception
+    {
+        ObjectMapper objectMapper = new ObjectMapper();
+        objectMapper.addMixIn(Pair2020.class, MyPairMixIn8.class);
+
+        String doc = a2q( "{'value0' : 456, 'value1' : 789}");
+        Pair2020 pair2 = objectMapper.readValue(doc, Pair2020.class);
+        assertEquals(456, pair2.x);
+        assertEquals(789, pair2.y);
+    }
 }
