@@ -1,10 +1,11 @@
 package com.fasterxml.jackson.databind.node;
 
 import com.fasterxml.jackson.databind.JsonNode;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
 
-import com.fasterxml.jackson.databind.BaseMapTest;
+import static org.junit.jupiter.api.Assertions.*;
 
-abstract class NodeTestBase extends BaseMapTest
+abstract class NodeTestBase extends DatabindTestUtil
 {
     protected void assertNodeNumbersForNonNumeric(JsonNode n)
     {
@@ -33,4 +34,16 @@ abstract class NodeTestBase extends BaseMapTest
 
         assertTrue(n.isEmpty());
     }
+
+    // Testing for non-ContainerNode (ValueNode) stream method implementations
+    //
+    // @since 2.19
+    protected void assertNonContainerStreamMethods(ValueNode n)
+    {
+        assertEquals(0, n.valueStream().count());
+        assertEquals(0, n.propertyStream().count());
+
+        // And then empty forEachEntry()
+        n.forEachEntry((k, v) -> { throw new UnsupportedOperationException(); });
+    }
 }
