@@ -3,11 +3,15 @@ package com.fasterxml.jackson.databind.node;
 import java.math.BigDecimal;
 import java.math.BigInteger;
 
+import org.junit.jupiter.api.Test;
+
 import com.fasterxml.jackson.core.JsonGenerator;
 import com.fasterxml.jackson.core.JsonParser;
 import com.fasterxml.jackson.core.JsonToken;
 import com.fasterxml.jackson.databind.*;
 
+import static org.junit.jupiter.api.Assertions.*;
+
 /**
  * Basic tests for {@link JsonNode} implementations that
  * contain numeric values.
@@ -16,6 +20,7 @@ public class NumberNodesTest extends NodeTestBase
 {
     private final ObjectMapper MAPPER = objectMapper();
 
+    @Test
     public void testShort()
     {
         ShortNode n = ShortNode.valueOf((short) 1);
@@ -38,8 +43,11 @@ public class NumberNodesTest extends NodeTestBase
         assertTrue(ShortNode.valueOf((short) 0).canConvertToLong());
         assertTrue(ShortNode.valueOf(Short.MAX_VALUE).canConvertToLong());
         assertTrue(ShortNode.valueOf(Short.MIN_VALUE).canConvertToLong());
+
+        assertNonContainerStreamMethods(n);
     }
 
+    @Test
     public void testIntViaMapper() throws Exception
     {
         int value = -90184;
@@ -69,6 +77,7 @@ public class NumberNodesTest extends NodeTestBase
         assertEquals(result, IntNode.valueOf(value));
     }
 
+    @Test
     public void testInt()
     {
         IntNode n = IntNode.valueOf(1);
@@ -94,8 +103,10 @@ public class NumberNodesTest extends NodeTestBase
         assertTrue(IntNode.valueOf(Integer.MAX_VALUE).canConvertToLong());
         assertTrue(IntNode.valueOf(Integer.MIN_VALUE).canConvertToLong());
 
+        assertNonContainerStreamMethods(n);
     }
 
+    @Test
     public void testLong()
     {
         LongNode n = LongNode.valueOf(1L);
@@ -122,8 +133,11 @@ public class NumberNodesTest extends NodeTestBase
         assertTrue(LongNode.valueOf(0L).canConvertToLong());
         assertTrue(LongNode.valueOf(Long.MAX_VALUE).canConvertToLong());
         assertTrue(LongNode.valueOf(Long.MIN_VALUE).canConvertToLong());
+
+        assertNonContainerStreamMethods(n);
     }
 
+    @Test
     public void testLongViaMapper() throws Exception
     {
         // need to use something beyond 32-bit value space
@@ -153,6 +167,7 @@ public class NumberNodesTest extends NodeTestBase
         assertEquals(result, LongNode.valueOf(value));
     }
 
+    @Test
     public void testDouble() throws Exception
     {
         DoubleNode n = DoubleNode.valueOf(0.25);
@@ -183,8 +198,11 @@ public class NumberNodesTest extends NodeTestBase
         n = (DoubleNode) num;
         assertEquals(-0.0, n.doubleValue());
         assertEquals("-0.0", String.valueOf(n.doubleValue()));
+
+        assertNonContainerStreamMethods(n);
     }
 
+    @Test
     public void testDoubleViaMapper() throws Exception
     {
         double value = 3.04;
@@ -213,6 +231,7 @@ public class NumberNodesTest extends NodeTestBase
     }
 
     // @since 2.2
+    @Test
     public void testFloat()
     {
         FloatNode n = FloatNode.valueOf(0.45f);
@@ -252,8 +271,11 @@ public class NumberNodesTest extends NodeTestBase
         assertTrue(FloatNode.valueOf(0L).canConvertToLong());
         assertTrue(FloatNode.valueOf(Integer.MAX_VALUE).canConvertToLong());
         assertTrue(FloatNode.valueOf(Integer.MIN_VALUE).canConvertToLong());
+
+        assertNonContainerStreamMethods(n);
     }
 
+    @Test
     public void testDecimalNode() throws Exception
     {
         DecimalNode n = DecimalNode.valueOf(BigDecimal.ONE);
@@ -309,8 +331,11 @@ public class NumberNodesTest extends NodeTestBase
 
         // also, equality should work ok
         assertEquals(result, DecimalNode.valueOf(value));
+
+        assertNonContainerStreamMethods(n);
     }
 
+    @Test
     public void testDecimalNodeEqualsHashCode()
     {
         // We want DecimalNodes with equivalent _numeric_ values to be equal;
@@ -336,6 +361,7 @@ public class NumberNodesTest extends NodeTestBase
         assertEquals(node3, node4);
     }
 
+    @Test
     public void testBigIntegerNode() throws Exception
     {
         BigIntegerNode n = BigIntegerNode.valueOf(BigInteger.ONE);
@@ -376,8 +402,11 @@ public class NumberNodesTest extends NodeTestBase
         assertTrue(BigIntegerNode.valueOf(BigInteger.ZERO).canConvertToLong());
         assertTrue(BigIntegerNode.valueOf(BigInteger.valueOf(Long.MAX_VALUE)).canConvertToLong());
         assertTrue(BigIntegerNode.valueOf(BigInteger.valueOf(Long.MIN_VALUE)).canConvertToLong());
+
+        assertNonContainerStreamMethods(n);
     }
 
+    @Test
     public void testBigDecimalAsPlain() throws Exception
     {
         ObjectMapper mapper = new ObjectMapper()
@@ -398,6 +427,7 @@ public class NumberNodesTest extends NodeTestBase
     }
 
     // Related to [databind#333]
+    @Test
     public void testCanonicalNumbers() throws Exception
     {
         JsonNodeFactory f = new JsonNodeFactory();
