@@ -1,11 +1,17 @@
 package com.fasterxml.jackson.databind.node;
 
-import com.fasterxml.jackson.databind.*;
+import org.junit.jupiter.api.Test;
 
-public class ToStringForNodesTest extends BaseMapTest
+import com.fasterxml.jackson.databind.*;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
+
+import static org.junit.jupiter.api.Assertions.*;
+
+public class ToStringForNodesTest extends DatabindTestUtil
 {
     private final ObjectMapper MAPPER = objectMapper();
 
+    @Test
     public void testObjectNode() throws Exception
     {
         _verifyToStrings(MAPPER.readTree("{ \"key\" : 1, \"b\" : \"x\", \"array\" : [ 1, false ] }"));
@@ -16,6 +22,7 @@ public class ToStringForNodesTest extends BaseMapTest
         assertEquals(expPretty, n.toPrettyString());
     }
 
+    @Test
     public void testArrayNode() throws Exception
     {
         _verifyToStrings(MAPPER.readTree("[ 1, true, null, [ \"abc\",3], { } ]"));
@@ -24,6 +31,7 @@ public class ToStringForNodesTest extends BaseMapTest
         assertEquals("[ 0.25, true ]", n.toPrettyString());
     }
 
+    @Test
     public void testBinaryNode() throws Exception
     {
         _verifyToStrings(MAPPER.getNodeFactory().binaryNode(new byte[] { 1, 2, 3, 4, 6 }));
