@@ -1,11 +1,16 @@
 package com.fasterxml.jackson.databind.node;
 
+import org.junit.jupiter.api.Test;
+
 import com.fasterxml.jackson.core.JsonPointer;
 import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.JsonNode.OverwriteMode;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
+
+import static org.junit.jupiter.api.Assertions.*;
 
 // for [databind#1980] implementation
-public class WithPathTest extends BaseMapTest
+public class WithPathTest extends DatabindTestUtil
 {
     private final ObjectMapper MAPPER = sharedMapper();
 
@@ -15,6 +20,7 @@ public class WithPathTest extends BaseMapTest
     /**********************************************************************
      */
 
+    @Test
     public void testValidWithObjectTrivial() throws Exception
     {
         ObjectNode root = MAPPER.createObjectNode();
@@ -22,12 +28,14 @@ public class WithPathTest extends BaseMapTest
         assertSame(root, match);
     }
 
+    @Test
     public void testValidWithObjectSimpleExisting() throws Exception
     {
         _testValidWithObjectSimpleExisting(true);
         _testValidWithObjectSimpleExisting(false);
     }
 
+    @Test
     public void testInvalidWithObjectTrivial() throws Exception
     {
         ArrayNode root = MAPPER.createArrayNode();
@@ -62,6 +70,7 @@ public class WithPathTest extends BaseMapTest
         assertEquals(DOC_STR, doc.toString());
     }
 
+    @Test
     public void testValidWithObjectSimpleCreate() throws Exception {
         _testValidWithObjectSimpleCreate(true);
         _testValidWithObjectSimpleCreate(false);
@@ -91,6 +100,7 @@ public class WithPathTest extends BaseMapTest
                 root.toString());
     }
 
+    @Test
     public void testValidWithObjectSimpleModify() throws Exception {
         _testValidWithObjectSimpleModify(true);
         _testValidWithObjectSimpleModify(false);
@@ -108,6 +118,7 @@ public class WithPathTest extends BaseMapTest
         assertEquals(a2q("{'a':{'b':42,'d':{}}}"), doc.toString());
     }
 
+    @Test
     public void testObjectPathWithReplace() throws Exception {
         _testObjectPathWithReplace(true);
         _testObjectPathWithReplace(false);
@@ -137,6 +148,7 @@ public class WithPathTest extends BaseMapTest
         _verifyObjectReplaceFail(root, abPath, OverwriteMode.NONE);
     }
 
+    @Test
     public void testValidWithObjectWithArray() throws Exception {
         _testValidWithObjectWithArray(true);
         _testValidWithObjectWithArray(false);
@@ -203,6 +215,7 @@ public class WithPathTest extends BaseMapTest
      */
 
     // [databind#4095]
+    @Test
     public void testWithObjectProperty() throws Exception
     {
         ObjectNode root = MAPPER.createObjectNode();
@@ -239,6 +252,7 @@ public class WithPathTest extends BaseMapTest
     }
 
     // [databind#4096]
+    @Test
     public void testWithObjectAdnExprOrProp() throws Exception
     {
         ObjectNode root = MAPPER.createObjectNode();
@@ -284,6 +298,7 @@ public class WithPathTest extends BaseMapTest
     /**********************************************************************
      */
 
+    @Test
     public void testValidWithArrayTrivial() throws Exception
     {
         // First, empty path, existing Array
@@ -303,11 +318,13 @@ public class WithPathTest extends BaseMapTest
     }
 
     // From Javadoc example
+    @Test
     public void testValidWithArraySimple() throws Exception {
         _testValidWithArraySimple(true);
         _testValidWithArraySimple(false);
     }
 
+    @Test
     public void testInvalidWithArrayTrivial() throws Exception
     {
         ArrayNode root = MAPPER.createArrayNode();
@@ -380,6 +397,7 @@ public class WithPathTest extends BaseMapTest
     }
 
     // [databind#3882]
+    @Test
     public void testWithArray3882() throws Exception
     {
         ObjectNode root = MAPPER.createObjectNode();
@@ -405,6 +423,7 @@ public class WithPathTest extends BaseMapTest
      */
 
     // [databind#4095]
+    @Test
     public void testWithArrayProperty() throws Exception
     {
         ObjectNode root = MAPPER.createObjectNode();
@@ -440,6 +459,7 @@ public class WithPathTest extends BaseMapTest
     }
 
     // [databind#4096]
+    @Test
     public void testWithArrayAndExprOrProp() throws Exception
     {
         ObjectNode root = MAPPER.createObjectNode();
