@@ -3,15 +3,21 @@ package com.fasterxml.jackson.databind.ser;
 import java.io.IOException;
 import java.util.*;
 
+import org.junit.jupiter.api.Test;
+
 import com.fasterxml.jackson.annotation.*;
+
 import com.fasterxml.jackson.core.JsonGenerator;
 import com.fasterxml.jackson.databind.*;
-import com.fasterxml.jackson.databind.ser.impl.*;
 import com.fasterxml.jackson.databind.annotation.JsonSerialize;
+import com.fasterxml.jackson.databind.ser.impl.*;
 import com.fasterxml.jackson.databind.ser.std.StdScalarSerializer;
 import com.fasterxml.jackson.databind.ser.std.StdSerializer;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
 
-public class AnyGetterTest extends BaseMapTest
+import static org.junit.jupiter.api.Assertions.*;
+
+public class AnyGetterTest extends DatabindTestUtil
 {
     static class Bean
     {
@@ -181,6 +187,25 @@ public class AnyGetterTest extends BaseMapTest
     }
 
     // [databind#1458]: Allow `@JsonAnyGetter` on fields too
+    static class DynaFieldOrderedBean {
+        public int id = 123;
+
+        @JsonPropertyOrder(alphabetic = true)
+        @JsonAnyGetter
+        @JsonAnySetter
+        private HashMap<String,String> other = new LinkedHashMap<>();
+
+        public Map<String,String> any() {
+            return other;
+        }
+
+        public void set(String name, String value) {
+            other.put(name, value);
+        }
+    }
+
+    // [databind#1458]: Allow `@JsonAnyGetter` on fields too
+    @Test
     public void testDynaFieldBean() throws Exception
     {
         DynaFieldBean b = new DynaFieldBean();
@@ -193,6 +218,18 @@ public class AnyGetterTest extends BaseMapTest
         assertEquals("Joe", result.other.get("name"));
     }
 
+    // [databind#4388]: Allow `@JsonPropertyOrder` AND `@JsonAnyGetter` on fields too
+    @Test
+    public void testDynaFieldOrderedBean() throws Exception
+    {
+        DynaFieldOrderedBean b = new DynaFieldOrderedBean();
+        b.set("nameC", "Cilly");
+        b.set("nameB", "Billy");
+        b.set("nameA", "Ailly");
+
+        assertEquals("{\"id\":123,\"nameA\":\"Ailly\",\"nameB\":\"Billy\",\"nameC\":\"Cilly\"}", MAPPER.writeValueAsString(b));
+    }
+
     /*
     /**********************************************************
     /* Test methods
@@ -201,6 +238,7 @@ public class AnyGetterTest extends BaseMapTest
 
     private final ObjectMapper MAPPER = newJsonMapper();
 
+    @Test
     public void testSimpleAnyBean() throws Exception
     {
         String json = MAPPER.writeValueAsString(new Bean());
@@ -210,6 +248,7 @@ public class AnyGetterTest extends BaseMapTest
         assertEquals(Boolean.TRUE, map.get("a"));
     }
 
+    @Test
     public void testAnyOnly() throws Exception
     {
         ObjectMapper m;
@@ -227,6 +266,7 @@ public class AnyGetterTest extends BaseMapTest
         assertEquals("{\"a\":3}", json);
     }
 
+    @Test
     public void testAnyDisabling() throws Exception
     {
         String json = MAPPER.writeValueAsString(new NotEvenAnyBean());
@@ -234,6 +274,7 @@ public class AnyGetterTest extends BaseMapTest
     }
 
     // Trying to repro [databind#577]
+    @Test
     public void testAnyWithNull() throws Exception
     {
         MapAsAny input = new MapAsAny();
@@ -242,6 +283,7 @@ public class AnyGetterTest extends BaseMapTest
                 MAPPER.writeValueAsString(input));
     }
 
+    @Test
     public void testIssue705() throws Exception
     {
         Issue705Bean input = new Issue705Bean("key", "value");
@@ -250,6 +292,7 @@ public class AnyGetterTest extends BaseMapTest
     }
 
     // [databind#1124]
+    @Test
     public void testAnyGetterWithValueSerializer() throws Exception
     {
         ObjectMapper mapper = new ObjectMapper();
@@ -260,10 +303,11 @@ public class AnyGetterTest extends BaseMapTest
     }
 
     // [databind#2592]
+    @Test
     public void testAnyGetterWithMapperDefaultIncludeNonEmpty() throws Exception
     {
         ObjectMapper mapper = new ObjectMapper()
-                .setSerializationInclusion(JsonInclude.Include.NON_EMPTY);
+                .setDefaultPropertyInclusion(JsonInclude.Include.NON_EMPTY);
         Bean2592NoAnnotations input = new Bean2592NoAnnotations();
         input.add("non-empty", "property");
         input.add("empty", "");
@@ -273,23 +317,24 @@ public class AnyGetterTest extends BaseMapTest
     }
 
     // [databind#2592]
+    @Test
     public void testAnyGetterWithMapperDefaultIncludeNonEmptyAndFilterOnBean() throws Exception
     {
         FilterProvider filters = new SimpleFilterProvider()
                 .addFilter("Bean2592", SimpleBeanPropertyFilter.serializeAllExcept("something"));
         ObjectMapper mapper = new ObjectMapper()
-                .setSerializationInclusion(JsonInclude.Include.NON_EMPTY)
+                .setDefaultPropertyInclusion(JsonInclude.Include.NON_EMPTY)
                 .setFilterProvider(filters);
         Bean2592WithFilter input = new Bean2592WithFilter();
         input.add("non-empty", "property");
         input.add("empty", "");
         input.add("null", null);
         String json = mapper.writeValueAsString(input);
-        // Unfortunately path for bean with filter is different. It still skips nulls.
-        assertEquals("{\"non-empty\":\"property\",\"empty\":\"\"}", json);
+        assertEquals("{\"non-empty\":\"property\"}", json);
     }
 
     // [databind#2592]
+    @Test
     public void testAnyGetterWithPropertyIncludeNonEmpty() throws Exception
     {
         ObjectMapper mapper = new ObjectMapper();
@@ -302,6 +347,7 @@ public class AnyGetterTest extends BaseMapTest
     }
 
     // [databind#2592]
+    @Test
     public void testAnyGetterConfigIncludeNonEmpty() throws Exception
     {
         final ObjectMapper mapper = jsonMapperBuilder()
