@@ -4,17 +4,23 @@ import java.io.StringWriter;
 import java.text.SimpleDateFormat;
 import java.util.*;
 
+import org.junit.jupiter.api.Test;
+
 import com.fasterxml.jackson.annotation.*;
+
 import com.fasterxml.jackson.core.JsonGenerator;
 import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.annotation.JsonSerialize;
 import com.fasterxml.jackson.databind.introspect.ClassIntrospector;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
+
+import static org.junit.jupiter.api.Assertions.*;
 
 /**
  * Unit tests for checking handling of SerializationConfig.
  */
 public class TestConfig
-    extends BaseMapTest
+    extends DatabindTestUtil
 {
     /*
     /**********************************************************
@@ -54,6 +60,7 @@ public class TestConfig
      * hit the limit, need to change implementation -- this test just
      * gives low-water mark
      */
+    @Test
     public void testEnumIndexes()
     {
         int max = 0;
@@ -66,11 +73,11 @@ public class TestConfig
         }
     }
 
+    @Test
     public void testDefaults()
     {
         SerializationConfig cfg = MAPPER.getSerializationConfig();
 
-        // First, defaults:
         assertTrue(cfg.isEnabled(MapperFeature.USE_ANNOTATIONS));
         assertTrue(cfg.isEnabled(MapperFeature.AUTO_DETECT_GETTERS));
         assertTrue(cfg.isEnabled(MapperFeature.CAN_OVERRIDE_ACCESS_MODIFIERS));
@@ -80,16 +87,17 @@ public class TestConfig
         assertFalse(cfg.isEnabled(SerializationFeature.INDENT_OUTPUT));
         assertFalse(cfg.isEnabled(MapperFeature.USE_STATIC_TYPING));
 
-        // since 1.3:
-        assertTrue(cfg.isEnabled(MapperFeature.AUTO_DETECT_IS_GETTERS));
-        // since 1.4
+        assertEquals(MapperFeature.AUTO_DETECT_IS_GETTERS.enabledByDefault(),
+                cfg.isEnabled(MapperFeature.AUTO_DETECT_IS_GETTERS));
 
-        assertTrue(cfg.isEnabled(SerializationFeature.FAIL_ON_EMPTY_BEANS));
-        // since 1.5
-        assertTrue(cfg.isEnabled(MapperFeature.DEFAULT_VIEW_INCLUSION));
+        assertEquals(SerializationFeature.FAIL_ON_EMPTY_BEANS.enabledByDefault(),
+               cfg.isEnabled(SerializationFeature.FAIL_ON_EMPTY_BEANS));
 
+        assertEquals(MapperFeature.DEFAULT_VIEW_INCLUSION.enabledByDefault(),
+                cfg.isEnabled(MapperFeature.DEFAULT_VIEW_INCLUSION));
     }
 
+    @Test
     public void testOverrideIntrospectors()
     {
         SerializationConfig cfg = MAPPER.getSerializationConfig();
@@ -99,6 +107,7 @@ public class TestConfig
         assertNull(cfg.getAnnotationIntrospector());
     }
 
+    @Test
     public void testMisc()
     {
         ObjectMapper m = new ObjectMapper();
@@ -106,6 +115,7 @@ public class TestConfig
         assertNotNull(m.getSerializationConfig().toString()); // ditto
     }
 
+    @Test
     public void testIndentation() throws Exception
     {
         Map<String,Integer> map = new HashMap<String,Integer>();
@@ -117,6 +127,7 @@ public class TestConfig
         assertEquals("{"+lf+"  \"a\" : 2"+lf+"}", result);
     }
 
+    @Test
     public void testAnnotationsDisabled() throws Exception
     {
         // first: verify that annotation introspection is enabled by default
@@ -134,23 +145,23 @@ public class TestConfig
     /**
      * Test for verifying working of [JACKSON-191]
      */
+    @Test
     public void testProviderConfig() throws Exception
     {
         ObjectMapper mapper = new ObjectMapper();
         DefaultSerializerProvider prov = (DefaultSerializerProvider) mapper.getSerializerProvider();
         assertEquals(0, prov.cachedSerializersCount());
         // and then should get one constructed for:
-        Map<String,Object> result = this.writeAndMap(mapper, new AnnoBean());
+        Map<String,Object> result = writeAndMap(mapper, new AnnoBean());
         assertEquals(2, result.size());
         assertEquals(Integer.valueOf(1), result.get("x"));
         assertEquals(Integer.valueOf(2), result.get("y"));
 
-        /* Note: it is 2 because we'll also get serializer for basic 'int', not
-         * just AnnoBean
-         */
-        /* 12-Jan-2010, tatus: Actually, probably more, if and when we typing
-         *   aspects are considered (depending on what is cached)
-         */
+        // Note: it is 2 because we'll also get serializer for basic 'int', not
+        // just AnnoBean
+
+        // 12-Jan-2010, tatus: Actually, probably more, if and when we typing
+        //    aspects are considered (depending on what is cached)
         int count = prov.cachedSerializersCount();
         if (count < 2) {
             fail("Should have at least 2 cached serializers, got "+count);
@@ -160,6 +171,7 @@ public class TestConfig
     }
 
     // Test for [Issue#12]
+    @Test
     public void testIndentWithPassedGenerator() throws Exception
     {
         Indentable input = new Indentable();
@@ -186,6 +198,7 @@ public class TestConfig
         assertEquals(INDENTED, sw.toString());
     }
 
+    @Test
     public void testNoAccessOverrides() throws Exception
     {
         ObjectMapper m = jsonMapperBuilder()
@@ -194,6 +207,7 @@ public class TestConfig
         assertEquals("{\"x\":1}", m.writeValueAsString(new SimpleBean()));
     }
 
+    @Test
     public void testDateFormatConfig() throws Exception
     {
         ObjectMapper mapper = new ObjectMapper();
