@@ -5,14 +5,13 @@ import java.io.StringWriter;
 import java.util.*;
 
 import javax.xml.parsers.DocumentBuilderFactory;
-
+import org.junit.jupiter.api.Test;
 import org.w3c.dom.Element;
 
 import com.fasterxml.jackson.annotation.*;
 
 import com.fasterxml.jackson.core.*;
 import com.fasterxml.jackson.core.io.CharacterEscapes;
-
 import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.annotation.JsonSerialize;
 import com.fasterxml.jackson.databind.module.SimpleModule;
@@ -21,15 +20,18 @@ import com.fasterxml.jackson.databind.ser.impl.SimpleFilterProvider;
 import com.fasterxml.jackson.databind.ser.std.CollectionSerializer;
 import com.fasterxml.jackson.databind.ser.std.StdDelegatingSerializer;
 import com.fasterxml.jackson.databind.ser.std.StdScalarSerializer;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
 import com.fasterxml.jackson.databind.type.TypeFactory;
 import com.fasterxml.jackson.databind.util.Converter;
 import com.fasterxml.jackson.databind.util.StdConverter;
 
+import static org.junit.jupiter.api.Assertions.*;
+
 /**
  * Tests for verifying various issues with custom serializers.
  */
 @SuppressWarnings("serial")
-public class TestCustomSerializers extends BaseMapTest
+public class TestCustomSerializers extends DatabindTestUtil
 {
     static class ElementSerializer extends JsonSerializer<Element>
     {
@@ -215,6 +217,11 @@ public class TestCustomSerializers extends BaseMapTest
                         return value == Super4575.NULL ? null : value;
                     }
 
+                    @Override
+                    public Object convert(SerializerProvider ctxt, Object value) {
+                        return value == Super4575.NULL ? null : value;
+                    }
+
                     @Override
                     public JavaType getInputType(TypeFactory typeFactory) {
                         return typeFactory.constructType(delegateSerializer.handledType());
@@ -244,6 +251,7 @@ public class TestCustomSerializers extends BaseMapTest
 
     private final ObjectMapper MAPPER = newJsonMapper();
 
+    @Test
     public void testCustomization() throws Exception
     {
         ObjectMapper objectMapper = new ObjectMapper();
@@ -255,10 +263,11 @@ public class TestCustomSerializers extends BaseMapTest
     }
 
     @SuppressWarnings({ "unchecked", "rawtypes" })
+    @Test
     public void testCustomLists() throws Exception
     {
         SimpleModule module = new SimpleModule("test", Version.unknownVersion());
-        JsonSerializer<?> ser = new CollectionSerializer(null, false, null, null);
+        JsonSerializer<?> ser = new CollectionSerializer(MAPPER.constructType(Object.class), false, null, null);
         final JsonSerializer<Object> collectionSerializer = (JsonSerializer<Object>) ser;
 
         module.addSerializer(Collection.class, new JsonSerializer<Collection>() {
@@ -280,6 +289,7 @@ public class TestCustomSerializers extends BaseMapTest
     }
 
     // [databind#87]: delegating serializer
+    @Test
     public void testDelegating() throws Exception
     {
         SimpleModule module = new SimpleModule("test", Version.unknownVersion());
@@ -301,24 +311,28 @@ public class TestCustomSerializers extends BaseMapTest
     }
 
     // [databind#215]: Allow registering CharacterEscapes via ObjectWriter
+    @Test
     public void testCustomEscapes() throws Exception
     {
         assertEquals(q("foo\\u0062\\Ar"),
                 MAPPER.writer(new CustomEscapes()).writeValueAsString("foobar"));
     }
 
+    @Test
     public void testNumberSubclass() throws Exception
     {
         assertEquals(a2q("{'x':42}"),
                 MAPPER.writeValueAsString(new LikeNumber(42)));
     }
 
+    @Test
     public void testWithCurrentValue() throws Exception
     {
         assertEquals(a2q("{'prop':'Issue631Bean/42'}"),
                 MAPPER.writeValueAsString(new Issue631Bean(42)));
     }
 
+    @Test
     public void testWithCustomElements() throws Exception
     {
         // First variant that uses per-property override
@@ -346,6 +360,7 @@ public class TestCustomSerializers extends BaseMapTest
     }
 
     // [databind#2475]
+    @Test
     public void testIssue2475() throws Exception {
         SimpleFilterProvider provider = new SimpleFilterProvider().addFilter("myFilter", new MyFilter2475());
         ObjectWriter writer = MAPPER.writer(provider);
@@ -360,6 +375,7 @@ public class TestCustomSerializers extends BaseMapTest
     }
 
     // [databind#4575]
+    @Test
     public void testIssue4575() throws Exception {
         com.fasterxml.jackson.databind.Module module = new SimpleModule() {
             {
