@@ -1,14 +1,19 @@
 package com.fasterxml.jackson.databind.ser.filter;
 
-import java.io.IOException;
 import java.util.*;
 
+import org.junit.jupiter.api.Test;
+
 import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonInclude;
 import com.fasterxml.jackson.annotation.JsonProperty;
 import com.fasterxml.jackson.annotation.JsonPropertyOrder;
+
 import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.annotation.JsonSerialize;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
+
+import static org.junit.jupiter.api.Assertions.*;
 
 /**
  * Unit tests for checking that alternative settings for
@@ -16,7 +21,7 @@ import com.fasterxml.jackson.databind.annotation.JsonSerialize;
  * as expected.
  */
 public class JsonIncludeTest
-    extends BaseMapTest
+    extends DatabindTestUtil
 {
     static class SimpleBean
     {
@@ -100,17 +105,10 @@ public class JsonIncludeTest
         }
     }
 
+    // [databind#4741]
     @JsonInclude(JsonInclude.Include.NON_DEFAULT)
     static class NonDefaultBean4741 {
-        private String value = null;
-
-        public String getValue() {
-            return value;
-        }
-
-        public void setValue(String value) {
-            this.value = value;
-        }
+        public String value = null;
     }
 
     static class NonEmptyString {
@@ -162,8 +160,19 @@ public class JsonIncludeTest
         public NonDefaultCalendar(Calendar v) { super(v); }
     }
 
-    // [databind#1351]
+    // [databind#1327]
+    @JsonInclude(JsonInclude.Include.NON_EMPTY)
+    static class Issue1327BeanEmpty {
+        public List<String> myList = new ArrayList<String>();
+    }
 
+    // [databind#1327]
+    static class Issue1327BeanAlways {
+        @JsonInclude(JsonInclude.Include.ALWAYS)
+        public List<String> myList = new ArrayList<String>();
+    }
+
+    // [databind#1351]
     static class Issue1351Bean
     {
         public final String first;
@@ -215,7 +224,8 @@ public class JsonIncludeTest
 
     final private ObjectMapper MAPPER = newJsonMapper();
 
-    public void testGlobal() throws IOException
+    @Test
+    public void testGlobal() throws Exception
     {
         Map<String,Object> result = writeAndMap(MAPPER, new SimpleBean());
         assertEquals(2, result.size());
@@ -224,7 +234,8 @@ public class JsonIncludeTest
         assertTrue(result.containsKey("b"));
     }
 
-    public void testNonNullByClass() throws IOException
+    @Test
+    public void testNonNullByClass() throws Exception
     {
         Map<String,Object> result = writeAndMap(MAPPER, new NoNullsBean());
         assertEquals(1, result.size());
@@ -234,7 +245,8 @@ public class JsonIncludeTest
         assertNull(result.get("b"));
     }
 
-    public void testNonDefaultByClass() throws IOException
+    @Test
+    public void testNonDefaultByClass() throws Exception
     {
         NonDefaultBean bean = new NonDefaultBean();
         // need to change one of defaults
@@ -248,14 +260,16 @@ public class JsonIncludeTest
     }
 
     // [databind#998]
-    public void testNonDefaultByClassNoCtor() throws IOException
+    @Test
+    public void testNonDefaultByClassNoCtor() throws Exception
     {
         NonDefaultBeanXYZ bean = new NonDefaultBeanXYZ(1, 2, 0);
         String json = MAPPER.writeValueAsString(bean);
         assertEquals(a2q("{'x':1,'y':2}"), json);
     }
 
-    public void testMixedMethod() throws IOException
+    @Test
+    public void testMixedMethod() throws Exception
     {
         MixedBean bean = new MixedBean();
         bean._a = "xyz";
@@ -273,28 +287,32 @@ public class JsonIncludeTest
         assertFalse(result.containsKey("a"));
     }
 
-    public void testDefaultForEmptyList() throws IOException
+    @Test
+    public void testDefaultForEmptyList() throws Exception
     {
         assertEquals("{}", MAPPER.writeValueAsString(new ListBean()));
     }
 
-    // NON_DEFAULT shoud work for arrays too
-    public void testNonEmptyDefaultArray() throws IOException
+    // NON_DEFAULT should work for arrays too
+    @Test
+    public void testNonEmptyDefaultArray() throws Exception
     {
         assertEquals("{}", MAPPER.writeValueAsString(new ArrayBean()));
     }
 
-    public void testDefaultForIntegers() throws IOException
+    @Test
+    public void testDefaultForIntegers() throws Exception
     {
         assertEquals("{}", MAPPER.writeValueAsString(new DefaultIntBean(0, Integer.valueOf(0))));
         assertEquals("{\"i2\":1}", MAPPER.writeValueAsString(new DefaultIntBean(0, Integer.valueOf(1))));
         assertEquals("{\"i1\":3}", MAPPER.writeValueAsString(new DefaultIntBean(3, Integer.valueOf(0))));
     }
 
-    public void testEmptyInclusionScalars() throws IOException
+    @Test
+    public void testEmptyInclusionScalars() throws Exception
     {
         ObjectMapper defMapper = MAPPER;
-        ObjectMapper inclMapper = new ObjectMapper().setSerializationInclusion(JsonInclude.Include.NON_EMPTY);
+        ObjectMapper inclMapper = new ObjectMapper().setDefaultPropertyInclusion(JsonInclude.Include.NON_EMPTY);
 
         // First, Strings
         StringWrapper str = new StringWrapper("");
@@ -319,11 +337,37 @@ public class JsonIncludeTest
         assertEquals("{\"i\":0}", inclMapper.writeValueAsString(zero));
     }
 
+    // for [databind#1327]
+    @Test
+    public void test1327ClassDefaultsForEmpty() throws Exception {
+        ObjectMapper om = new ObjectMapper();
+        om.setDefaultPropertyInclusion(JsonInclude.Include.NON_NULL);
+
+        final String jsonString = om.writeValueAsString(new Issue1327BeanEmpty());
+
+        if (jsonString.contains("myList")) {
+            fail("Should not contain `myList`: "+jsonString);
+        }
+    }
+
+    @Test
+    public void test1327ClassDefaultsForAlways() throws Exception {
+        ObjectMapper om = new ObjectMapper();
+        om.setDefaultPropertyInclusion(JsonInclude.Include.NON_EMPTY);
+
+        final String jsonString = om.writeValueAsString(new Issue1327BeanAlways());
+
+        if (!jsonString.contains("myList")) {
+            fail("Should contain `myList` with Include.ALWAYS: "+jsonString);
+        }
+    }    
+
     // [databind#1351], [databind#1417]
+    @Test
     public void testIssue1351() throws Exception
     {
         ObjectMapper mapper = new ObjectMapper();
-        mapper.setSerializationInclusion(JsonInclude.Include.NON_DEFAULT);
+        mapper.setDefaultPropertyInclusion(JsonInclude.Include.NON_DEFAULT);
         assertEquals(a2q("{}"),
                 mapper.writeValueAsString(new Issue1351Bean(null, (double) 0)));
         // [databind#1417]
@@ -332,15 +376,16 @@ public class JsonIncludeTest
     }
 
     // [databind#4741]
+    @Test
     public void testSerialization4741() throws Exception
     {
-        ObjectMapper mapper = new ObjectMapper();
         NonDefaultBean4741 bean = new NonDefaultBean4741();
-        bean.setValue("");
-        assertEquals(a2q("{'value':''}"), mapper.writeValueAsString(bean));
+        bean.value = "";
+        assertEquals(a2q("{'value':''}"), MAPPER.writeValueAsString(bean));
     }
 
     // [databind#1550]
+    @Test
     public void testInclusionOfDate() throws Exception
     {
         final Date input = new Date(0L);
@@ -353,6 +398,7 @@ public class JsonIncludeTest
     }
 
     // [databind#1550]
+    @Test
     public void testInclusionOfCalendar() throws Exception
     {
         final Calendar input = new GregorianCalendar();
