@@ -2,13 +2,19 @@ package com.fasterxml.jackson.databind.struct;
 
 import java.util.*;
 
+import org.junit.jupiter.api.Test;
+
 import com.fasterxml.jackson.annotation.*;
+
 import com.fasterxml.jackson.databind.*;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
+
+import static org.junit.jupiter.api.Assertions.*;
 
 /**
  * Tests for {@link JsonFormat} and specifically <code>JsonFormat.Feature</code>s.
  */
-public class FormatFeatureOrderedMapTest extends BaseMapTest
+public class FormatFeatureOrderedMapTest extends DatabindTestUtil
 {
     static class SortedKeysMap {
         @JsonFormat(with = JsonFormat.Feature.WRITE_SORTED_MAP_ENTRIES)
@@ -22,14 +28,15 @@ public class FormatFeatureOrderedMapTest extends BaseMapTest
         }
     }
 
-    private final ObjectMapper MAPPER = new ObjectMapper();
+    private final ObjectMapper MAPPER = newJsonMapper();
 
     // [databind#1232]: allow forcing sorting on Map keys
+    @Test
     public void testOrderedMaps() throws Exception {
         SortedKeysMap map = new SortedKeysMap()
             .put("b", 2)
             .put("a", 1);
-        assertEquals(aposToQuotes("{'values':{'a':1,'b':2}}"),
+        assertEquals(a2q("{'values':{'a':1,'b':2}}"),
                 MAPPER.writeValueAsString(map));
     }
 }
