@@ -1,10 +1,16 @@
 package com.fasterxml.jackson.databind.struct;
 
+import org.junit.jupiter.api.Test;
+
 import com.fasterxml.jackson.annotation.JsonInclude;
 import com.fasterxml.jackson.annotation.JsonUnwrapped;
-import com.fasterxml.jackson.databind.*;
 
-public class UnwrappedWithView1559Test extends BaseMapTest
+import com.fasterxml.jackson.databind.*;
+import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
+
+import static org.junit.jupiter.api.Assertions.*;
+
+public class UnwrappedWithView1559Test extends DatabindTestUtil
 {
     @JsonInclude(JsonInclude.Include.NON_EMPTY)
     static final class Health {
@@ -24,13 +30,16 @@ public class UnwrappedWithView1559Test extends BaseMapTest
      */
 
     // for [databind#1559]
+    @Test
     public void testCanSerializeSimpleWithDefaultView() throws Exception {
-        String json = new ObjectMapper().configure(MapperFeature.DEFAULT_VIEW_INCLUSION, false)
+        String json = jsonMapperBuilder().configure(MapperFeature.DEFAULT_VIEW_INCLUSION, false)
+                .build()
                 .writeValueAsString(new Health());
-        assertEquals(aposToQuotes("{}"), json);
+        assertEquals(a2q("{}"), json);
         // and just in case this, although won't matter wrt output
-        json = new ObjectMapper().configure(MapperFeature.DEFAULT_VIEW_INCLUSION, true)
+        json = jsonMapperBuilder().configure(MapperFeature.DEFAULT_VIEW_INCLUSION, true)
+                .build()
                 .writeValueAsString(new Health());
-        assertEquals(aposToQuotes("{}"), json);
+        assertEquals(a2q("{}"), json);
     }
 }
