@@ -4,7 +4,7 @@ import org.junit.jupiter.api.Test;
 
 import com.fasterxml.jackson.databind.testutil.DatabindTestUtil;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
 public class NameTransformerTest extends DatabindTestUtil
 {
